from fastapi import APIRouter, Form, File, UploadFile
from pydantic import BaseModel
import azure.cosmos.exceptions as exceptions
from ..database.mycosmosdb import callConnect
from ..storage.upload import upload_to_azure_blob

import concurrent.futures
from typing import List, Optional, Union
from .utils import get_files, get_year_qtr_files_data
import logging


class CMets(BaseModel):
    oid: str
    email: str


class GTMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    label: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
    s6: str


class FrogMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: bool
    m6: Optional[bool]
    m7: Optional[bool]
    m8: Optional[bool]
    m9: Optional[bool]
    m10: Optional[bool]
    label: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
    s6: str
    s7: str
    s8: str
    s9: str
    s10: str
    s11: str
    s12: str
    s13: str
    s14: str
    s15: Optional[str]
    s16: Optional[str]


class RenewMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    m1: Union[str, bool]
    m2: Union[str, bool]
    m3: Union[str, bool]
    m4: Union[str, bool]
    m5: Union[str, bool]
    m6: Optional[bool]
    m7: Optional[bool]
    m8: Optional[bool]
    m9: Optional[bool]
    m10: Optional[bool]
    m11: Optional[bool]
    m12: Optional[bool]
    m13: Optional[bool]
    m14: Optional[bool]
    m15: Optional[bool]
    m16: Optional[bool]
    label: str
    s1: str
    s2: str
    s3: str
    s4: Optional[str]
    s5: Optional[str]
    s6: Optional[str]
    s7: Optional[str]
    s8: Optional[str]
    s9: Optional[str]
    s10: Optional[str]
    s11: Optional[str]
    s12: Optional[str]
    s13: Optional[str]
    s14: Optional[str]
    s15: Optional[str]
    s16: Optional[str]
    s17: Optional[str]
    s18: Optional[str]
    s19: Optional[str]
    s20: Optional[str]
    s21: Optional[str]
    s22: Optional[str]
    s23: Optional[str]
    s24: Optional[str]
    s25: Optional[str]
    s26: Optional[str]
    s27: Optional[str]
    s28: Optional[str]
    s29: Optional[str]
    s30: Optional[str]
    s31: Optional[str]
    s32: Optional[str]
    s33: Optional[str]
    s34: Optional[str]
    s35: Optional[str]
    s36: Optional[str]
    s37: Optional[str]
    s38: Optional[str]
    s39: Optional[str]
    s40: Optional[str]
    s41: Optional[str]
    s42: Optional[str]
    s43: Optional[str]
    s44: Optional[str]
    s45: Optional[str]
    s46: Optional[str]
    s47: Optional[str]
    s48: Optional[str]
    s49: Optional[str]
    s50: Optional[str]


class RenewDiv(BaseModel):
    oid: str
    email: str
    metric: str
    m1: Union[str, bool]
    m2: Union[str, bool]
    m3: Union[str, bool]
    m4: Union[str, bool]
    m5: Union[str, bool]
    label: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
    s6: str
    s7: str
    s8: str
    s9: str
    s10: str
    s11: str
    s12: str
    s13: str
    s14: str
    s15: str
    s16: str
    s17: str
    s18: str
    s19: str
    s20: str
    s21: str
    s22: str
    s23: str
    s24: str
    s25: str
    s26: str
    s27: str
    s28: str


class IMMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    label: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
    s6: str
    s7: str
    s8: str
    s9: str
    s10: str
    s11: str
    s12: str
    s13: str
    s14: str
    s15: str
    s16: str


class Metric(BaseModel):
    label: str
    value: str


class Metrics(BaseModel):
    year: str
    metrics: List[Metric]


class CompanyReq(BaseModel):
    id: str
    email: str
    industry: str
    oid: str
    investor: str
    investorFund: str
    city: Optional[str] = None
    state: Optional[str] = None
    country: Optional[str] = None
    fundingStage: Optional[str] = None

class CompanyReqL(BaseModel):
    lss: List[CompanyReq]

class CompanyReq2(BaseModel):
    id: str
    email: str
    industry: str
    oid: str
class CompanyReqL2(BaseModel):
    lss: List[CompanyReq2]


class QuonaMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: Optional[bool]
    m6: Optional[bool]
    m7: Optional[bool]
    m8: Optional[bool]
    m9: Optional[bool]
    m10: Optional[bool]
    m11: Optional[bool]
    m12: Optional[bool]
    m13: Optional[bool]
    m14: Optional[bool]
    m15: Optional[bool]
    m16: Optional[bool]
    label: str
    s1: str
    s2: str
    s3: Optional[str]
    s4: Optional[str]
    s5: Optional[str]
    s6: Optional[str]
    s7: Optional[str]
    s8: Optional[str]
    s9: Optional[str]
    s10: Optional[str]
    s11: Optional[str]
    s12: Optional[str]
    s13: Optional[str]
    s14: Optional[str]
    s15: Optional[str]
    s16: Optional[str]
    s17: Optional[str]
    s18: Optional[str]
    s19: Optional[str]
    s20: Optional[str]
    s21: Optional[str]
    s22: Optional[str]
    s23: Optional[str]
    s24: Optional[str]
    s25: Optional[str]
    s26: Optional[str]
    s27: Optional[str]
    s28: Optional[str]
    s29: Optional[str]
    s30: Optional[str]
    s31: Optional[str]

class ActivateMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: Optional[bool]
    m6: Optional[bool]
    m7: Optional[bool]
    m8: Optional[bool]
    m9: Optional[bool]
    m10: Optional[bool]
    m11: Optional[bool]
    m12: Optional[bool]
    m13: Optional[bool]
    m14: Optional[bool]
    m15: Optional[bool]
    m16: Optional[bool]
    label: str
    s1: str
    s2: str
    s3: Optional[str]
    s4: Optional[str]
    s5: Optional[str]
    s6: Optional[str]
    s7: Optional[str]
    s8: Optional[str]
    s9: Optional[str]
    s10: Optional[str]
    s11: Optional[str]
    s12: Optional[str]
    s13: Optional[str]
    s14: Optional[str]
    s15: Optional[str]
    s16: Optional[str]
    s17: Optional[str]
    s18: Optional[str]
    s19: Optional[str]
    s20: Optional[str]
    s21: Optional[str]
    s22: Optional[str]
    s23: Optional[str]
    s24: Optional[str]
    s25: Optional[str]
    s26: Optional[str]
    s27: Optional[str]
    s28: Optional[str]
    s29: Optional[str]
    s30: Optional[str]
    s31: Optional[str]
    s32: Optional[str]
    s33: Optional[str]
    s34: Optional[str]
    s35: Optional[str]
    s36: Optional[str]
    s37: Optional[str]
    s38: Optional[str]
    s39: Optional[str]
    s40: Optional[str]
    s41: Optional[str]
    s42: Optional[str]
    s43: Optional[str]
    s44: Optional[str]
    s45: Optional[str]
    s46: Optional[str]
    s47: Optional[str]


class PivaMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: Optional[bool]
    m6: Optional[bool]
    m7: Optional[bool]
    m8: Optional[bool]
    m9: Optional[bool]
    m10: Optional[bool]
    m11: Optional[bool]
    m12: Optional[bool]
    m13: Optional[bool]
    m14: Optional[bool]
    m15: Optional[bool]
    m16: Optional[bool]
    label: str
    s1: str
    s2: str
    s3: Optional[str]
    s4: Optional[str]
    s5: Optional[str]
    s6: Optional[str]
    s7: Optional[str]
    s8: Optional[str]
    s9: Optional[str]
    s10: Optional[str]
    s11: Optional[str]
    s12: Optional[str]
    s13: Optional[str]
    s14: Optional[str]
    s15: Optional[str]
    s16: Optional[str]
    s17: Optional[str]
    s18: Optional[str]
    s19: Optional[str]
    s20: Optional[str]
    s21: Optional[str]
    s22: Optional[str]
    s23: Optional[str]
    s24: Optional[str]
    s25: Optional[str]
    s26: Optional[str]
    s27: Optional[str]
    s28: Optional[str]
    s29: Optional[str]
    s30: Optional[str]
    s31: Optional[str]
    s32: Optional[str]
    s33: Optional[str]
    s34: Optional[str]
    s35: Optional[str]
    s36: Optional[str]
    s37: Optional[str]
    s38: Optional[str]
    s39: Optional[str]
    s40: Optional[str]
    s41: Optional[str]
    s42: Optional[str]
    s43: Optional[str]
    s44: Optional[str]
    s45: Optional[str]
    s46: Optional[str]


class GreenbackerMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: Optional[bool]
    m6: Optional[bool]
    m7: Optional[bool]
    m8: Optional[bool]
    m9: Optional[bool]
    m10: Optional[bool]
    m11: Optional[bool]
    m12: Optional[bool]
    m13: Optional[bool]
    m14: Optional[bool]
    m15: Optional[bool]
    m16: Optional[bool]
    m17: Optional[bool]
    m18: Optional[bool]
    m19: Optional[bool]
    m20: Optional[bool]
    m21: Optional[bool]
    m22: Optional[bool]
    m23: Optional[bool]
    m24: Optional[bool]
    m25: Optional[bool]
    m26: Optional[bool]
    m27: Optional[bool]
    label: str
    s1: str
    s2: str
    s3: Optional[str]
    s4: Optional[str]
    s5: Optional[str]
    s6: Optional[str]
    s7: Optional[str]
    s8: Optional[str]
    s9: Optional[str]
    s10: Optional[str]
    s11: Optional[str]
    s12: Optional[str]
    s13: Optional[str]
    s14: Optional[str]
    s15: Optional[str]
    s16: Optional[str]
    s17: Optional[str]
    s18: Optional[str]
    s19: Optional[str]
    s20: Optional[str]
    s21: Optional[str]
    s22: Optional[str]
    s23: Optional[str]
    s24: Optional[str]
    s25: Optional[str]
    s26: Optional[str]
    s27: Optional[str]
    s28: Optional[str]
    s29: Optional[str]
    s30: Optional[str]
    s31: Optional[str]
    s32: Optional[str]
    s33: Optional[str]
    s34: Optional[str]
    s35: Optional[str]
    s36: Optional[str]
    s37: Optional[str]
    s38: Optional[str]
    s39: Optional[str]
    s40: Optional[str]
    s41: Optional[str]
    s42: Optional[str]
    s43: Optional[str]
    s44: Optional[str]
    s45: Optional[str]
    s46: Optional[str]
    s47: Optional[str]
    s48: Optional[str]
    s49: Optional[str]
    s50: Optional[str]
    s51: Optional[str]
    s52: Optional[str]
    s53: Optional[str]
    s54: Optional[str]
    s55: Optional[str]


class CBIVMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: Optional[bool]
    m6: Optional[bool]
    m7: Optional[bool]
    m8: Optional[bool]
    m9: Optional[bool]
    m10: Optional[bool]
    m11: Optional[bool]
    m12: Optional[bool]
    m13: Optional[bool]
    m14: Optional[bool]
    m15: Optional[bool]
    m16: Optional[bool]
    m17: Optional[bool]
    m18: Optional[bool]
    m19: Optional[bool]
    m20: Optional[bool]
    m21: Optional[bool]
    m22: Optional[bool]
    m23: Optional[bool]
    m24: Optional[bool]
    m25: Optional[bool]
    m26: Optional[bool]
    m27: Optional[bool]
    m28: Optional[bool]
    m29: Optional[bool]
    m30: Optional[bool]
    label: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: Optional[str]
    s6: Optional[str]
    s7: Optional[str]
    s8: Optional[str]
    s9: Optional[str]
    s10: Optional[str]
    s11: Optional[str]
    s12: Optional[str]
    s13: Optional[str]
    s14: Optional[str]
    s15: Optional[str]
    s16: Optional[str]
    s17: Optional[str]
    s18: Optional[str]
    s19: Optional[str]
    s20: Optional[str]
    s21: Optional[str]
    s22: Optional[str]
    s23: Optional[str]
    s24: Optional[str]
    s25: Optional[str]
    s26: Optional[str]
    s27: Optional[str]
    s28: Optional[str]
    s29: Optional[str]
    s30: Optional[str]
    s31: Optional[str]
    s32: Optional[str]
    s33: Optional[str]
    s34: Optional[str]
    s35: Optional[str]
    s36: Optional[str]
    s37: Optional[str]


class CarbonMeasure(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: bool
    label: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
    s6: str
    s7: str
    s8: str
    s9: str
    s10: Optional[str]
    s11: Optional[List[str]]
    persistYear: Optional[str]
    persistQuar: Optional[str]

class CarbonMeasureEdit2(BaseModel):
    oid: str
    email: str
    metric: str
    m1: bool
    m2: bool
    m3: bool
    m4: bool
    m5: bool
    label: str
    s1: str
    s2: str
    s3: str
    s4: str
    s5: str
    s6: str
    s7: str
    s8: str
    s9: str
    s10: str
    s11: str
    s12: str
    s13: Optional[str]
    s14: Optional[str]
    s15: Optional[List[str]]
    s16: Optional[List[str]]
    persistYear: Optional[str]
    persistQuar: Optional[str]


customsroute = APIRouter()


def read_item(container, doc_id, account_number):
    response = container.read_item(item=doc_id, partition_key=account_number)
    return response


def Convert(a):
    it = iter(a)
    res_dct = dict(zip(it, it))
    return res_dct


def read_conc(listReq):
    ax = dict(listReq)
    try:
        response = read_item(callConnect.container15, ax["oid"], ax["email"])
    except exceptions.CosmosHttpResponseError as e:
        logging.error(
            f'The fund with oid "{ax["oid"]}" was not found on the database.')
        return {}

    if response:
        if "city" in ax:
            return {"cmets": response["custommeasure"], "id": ax["id"], "industry": ax["industry"], "investor": ax["investor"], "investorFund": ax["investorFund"], "city": ax["city"], "state": ax["state"], "country": ax["country"], "fundingStage": ax["fundingStage"]}
        else:
            return {"cmets": response["custommeasure"], "id": ax["investor"], "industry": ax["industry"], "investorFund": ax["investorFund"]}

def read_green(listReq):
    ax = dict(listReq)
    try:
        response = read_item(callConnect.container15, ax["oid"], ax["email"])
    except exceptions.CosmosHttpResponseError as e:
        logging.error(
            f'The fund with oid "{ax["oid"]}" was not found on the database.')
        return {}

    if response:
        return {"cmets": response["custommeasure"], "id": ax["id"]}


"""
Endpoint used to grab all of the carbon measure pages in the DB
"""


@customsroute.post('/getcustommeasure')
async def get_custom_measure(cmet: CMets):
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /getcustommeasure')
        pass

    if "custommeasure" in db_result:
        return {"cmets": db_result["custommeasure"]}


"""
Endpoint used to grab all of the carbon measure pages in the DB
"""


@customsroute.post('/getnsky')
async def get_custom_measure(cmet: CompanyReqL):
    resp = []
    with concurrent.futures.ThreadPoolExecutor() as executor:
        results = executor.map(read_conc, cmet.lss)
    if results:
        for x in results:
            resp.append(x)

    return resp


"""
Endpoint used to grab all of the carbon measure pages in the DB
"""
@customsroute.post('/getgreenlist')
async def get_custom_measure(cmet: CompanyReqL2):
    resp = []
    with concurrent.futures.ThreadPoolExecutor() as executor:
        results = executor.map(read_green, cmet.lss)
    if results:
        for x in results:
            resp.append(x)

    return resp


"""
Endpoint used to update the custom metrics
"""
@customsroute.post('/custommeasure')
async def custom_measure(cmet: GTMeasure):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "GovernanceTurnover":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "GovernanceTurnover"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GovernanceTurnover"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "GovernanceTurnover"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "environmental": cmet.m1,
                            "risk": cmet.m2,
                            "diversity": cmet.m3,
                            "discrimination": cmet.m4,
                            "newEmployees": cmet.s1,
                            "departEmployees": cmet.s2,
                            "averageEmployees": cmet.s3,
                            "turnoverRate": cmet.s4
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GovernanceTurnover",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "environmental": cmet.m1,
                            "risk": cmet.m2,
                            "diversity": cmet.m3,
                            "discrimination": cmet.m4,
                            "newEmployees": cmet.s1,
                            "departEmployees": cmet.s2,
                            "averageEmployees": cmet.s3,
                            "turnoverRate": cmet.s4
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GovernanceTurnover",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "GovernanceTurnover"]
                    newMet = {
                        "label": "GovernanceTurnover",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "environmental": cmet.m1,
                                                            "risk": cmet.m2,
                                                            "diversity": cmet.m3,
                                                            "discrimination": cmet.m4,
                                                            "newEmployees": cmet.s1,
                                                            "departEmployees": cmet.s2,
                                                            "averageEmployees": cmet.s3,
                                                            "turnoverRate": cmet.s4
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
    else:
        pass


"""
Endpoint used to update the custom metrics frog
"""
@customsroute.post('/custommeasureFROG')
async def custom_measure_frog(cmet: FrogMeasure):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "GovernanceTurnover":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "GovernanceTurnover"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GovernanceTurnover"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "GovernanceTurnover"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "environmental": cmet.m1,
                            "risk": cmet.m2,
                            "diversity": cmet.m3,
                            "discrimination": cmet.m4,
                            "whistleBlowing": cmet.m5,
                            "dataSecurity": cmet.m6,
                            "codeConduct": cmet.m7,
                            "familyLeavePolicy": cmet.m8,
                            "maternityLeave": cmet.m9,
                            "paternityLeave": cmet.m10,
                            "newEmployeesW": cmet.s1,
                            "departEmployeesW": cmet.s2,
                            "averageEmployeesW": cmet.s3,
                            "turnoverRate": cmet.s4,
                            "newEmployeesM": cmet.s7,
                            "departEmployeesM": cmet.s8,
                            "averageEmployeesM": cmet.s9,
                            "newEmployeesN": cmet.s10,
                            "departEmployeesN": cmet.s11,
                            "averageEmployeesN": cmet.s12,
                            "newEmployeesT": cmet.s13,
                            "departEmployeesT": cmet.s14,
                            "averageEmployeesT": cmet.s15
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GovernanceTurnover",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "environmental": cmet.m1,
                            "risk": cmet.m2,
                            "diversity": cmet.m3,
                            "discrimination": cmet.m4,
                            "whistleBlowing": cmet.m5,
                            "dataSecurity": cmet.m6,
                            "codeConduct": cmet.m7,
                            "familyLeavePolicy": cmet.m8,
                            "maternityLeave": cmet.m9,
                            "paternityLeave": cmet.m10,
                            "newEmployeesW": cmet.s1,
                            "departEmployeesW": cmet.s2,
                            "averageEmployeesW": cmet.s3,
                            "turnoverRate": cmet.s4,
                            "newEmployeesM": cmet.s7,
                            "departEmployeesM": cmet.s8,
                            "averageEmployeesM": cmet.s9,
                            "newEmployeesN": cmet.s10,
                            "departEmployeesN": cmet.s11,
                            "averageEmployeesN": cmet.s12,
                            "newEmployeesT": cmet.s13,
                            "departEmployeesT": cmet.s14,
                            "averageEmployeesT": cmet.s15
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GovernanceTurnover",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "GovernanceTurnover"]
                    newMet = {
                        "label": "GovernanceTurnover",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "environmental": cmet.m1,
                                                            "risk": cmet.m2,
                                                            "diversity": cmet.m3,
                                                            "discrimination": cmet.m4,
                                                            "whistleBlowing": cmet.m5,
                                                            "dataSecurity": cmet.m6,
                                                            "codeConduct": cmet.m7,
                                                            "familyLeavePolicy": cmet.m8,
                                                            "maternityLeave": cmet.m9,
                                                            "paternityLeave": cmet.m10,
                                                            "newEmployeesW": cmet.s1,
                                                            "departEmployeesW": cmet.s2,
                                                            "averageEmployeesW": cmet.s3,
                                                            "turnoverRate": cmet.s4,
                                                            "newEmployeesM": cmet.s7,
                                                            "departEmployeesM": cmet.s8,
                                                            "averageEmployeesM": cmet.s9,
                                                            "newEmployeesN": cmet.s10,
                                                            "departEmployeesN": cmet.s11,
                                                            "averageEmployeesN": cmet.s12,
                                                            "newEmployeesT": cmet.s13,
                                                            "departEmployeesT": cmet.s14,
                                                            "averageEmployeesT": cmet.s15
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "FrogImpactQuestionnaireProgress":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [_item for _item in db_resultC["carbonmeasure"]
                              if _item["label"] != "Emissions"]

                    if ([_item for _item in db_resultC["carbonmeasure"] if _item["label"] == "Emissions"]):
                        emData = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] == "Emissions"][0]

                        if ([_item for _item in emData["metrics"] if _item["label"] == cmet.s5]):
                            yearData2C = [
                                _item for _item in emData["metrics"] if _item["label"] == cmet.s5][0]
                            if ([_item for _item in yearData2C["value"] if _item["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    _item for _item in yearData2C["value"] if _item["label"] != cmet.s6]
                                customMeasurement2C = []
                                customMeasurement2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [_item for _item in emData["metrics"]
                                           if _item["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            customMeasurement2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [_item for _item in emData["metrics"]
                                       if _item["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": customMeasurement2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [_item for _item in db_result["custommeasure"] if _item["label"] != "FrogImpactQuestionnaireProgress"]

                if ([_item for _item in db_result["custommeasure"] if _item["label"] == "FrogImpactQuestionnaireProgress"]):
                    remoteData = [_item for _item in db_result["custommeasure"] if _item["label"] == "FrogImpactQuestionnaireProgress"][0]
                    if ([_item for _item in remoteData["metrics"] if _item["label"] == cmet.s5]):
                        yearData = [_item for _item in remoteData["metrics"]
                                    if _item["label"] == cmet.s5][0]
                        quarterData = [
                            _item for _item in yearData["value"] if _item["label"] != cmet.s6]
                        customMeasurement = []
                        customMeasurement.append({
                            # Environment
                            # Scope emissions
                            "scope-1-emissions": cmet.s1,
                            "scope-2-emissions": cmet.s2,
                            # Scope 2 intermediate pro2ress
                            "scope-2-remote-workers": cmet.s3,
                            "scope-2-electricity": cmet.s4,
                            "scope-2-heat-and-steam": cmet.s7,
                            "scope-3-emissions": cmet.s8,
                            # Scope 3 intermediate progress
                            "scope-3-travel": cmet.s9,
                            "scope-3-commuting": cmet.s10,
                            "scope-3-cloud": cmet.s11,
                            # Social
                            "gender-diversity": cmet.s12,
                            "racial-diversity": cmet.s13,
                            # Governance
                            "policy": cmet.s14,
                            "turnover": cmet.s15,
                            # Social
                            "employee-overview": cmet.s16,
                        })
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": customMeasurement
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "FrogImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        customMeasurement = [{
                            # Environment
                            # Scope emissions
                            "scope-1-emissions": cmet.s1,
                            "scope-2-emissions": cmet.s2,
                            # Scope 2 intermediate pro2ress
                            "scope-2-remote-workers": cmet.s3,
                            "scope-2-electricity": cmet.s4,
                            "scope-2-heat-and-steam": cmet.s7,
                            "scope-3-emissions": cmet.s8,
                            # Scope 3 intermediate progress
                            "scope-3-travel": cmet.s9,
                            "scope-3-commuting": cmet.s10,
                            "scope-3-cloud": cmet.s11,
                            # Social
                            "gender-diversity": cmet.s12,
                            "racial-diversity": cmet.s13,
                            # Governance
                            "policy": cmet.s14,
                            "turnover": cmet.s15,
                            # Social
                            "employee-overview": cmet.s16,
                        }]
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "FrogImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [_item for _item in db_result["custommeasure"]
                            if _item["label"] != "FrogImpactQuestionnaireProgress"]
                    newMet = {
                        "label": "FrogImpactQuestionnaireProgress",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            # Environment
                                                            # Scope emissions
                                                            "scope-1-emissions": cmet.s1,
                                                            "scope-2-emissions": cmet.s2,
                                                            # Scope 2 intermediate pro2ress
                                                            "scope-2-remote-workers": cmet.s3,
                                                            "scope-2-electricity": cmet.s4,
                                                            "scope-2-heat-and-steam": cmet.s7,
                                                            "scope-3-emissions": cmet.s8,
                                                            # Scope 3 intermediate progress
                                                            "scope-3-travel": cmet.s9,
                                                            "scope-3-commuting": cmet.s10,
                                                            "scope-3-cloud": cmet.s11,
                                                            # Social
                                                            "gender-diversity": cmet.s12,
                                                            "racial-diversity": cmet.s13,
                                                            # Governance
                                                            "policy": cmet.s14,
                                                            "turnover": cmet.s15,
                                                            # Social
                                                            "employee-overview": cmet.s16,
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "SocialImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "SocialImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "SocialImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "SocialImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "var1": cmet.s1,
                            "var2": cmet.s2
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "var1": cmet.s1,
                            "var2": cmet.s2
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "SocialImpact"]
                    newMet = {
                        "label": "SocialImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)        
    else:
        pass


"""
Endpoint used to update the custom metrics for renew measurement
"""
@customsroute.post('/custommeasureRenewalF')
async def custom_measure_renew(cmet: RenewMeasure):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "EnvironmentalImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "EnvironmentalImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "EnvironmentalImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "EnvironmentalImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "EnvironmentalImpact"]
                    newMet = {
                        "label": "EnvironmentalImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "SocialImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "SocialImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "SocialImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "SocialImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "SocialImpact"]
                    newMet = {
                        "label": "SocialImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "GovernanceImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "GovernanceImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "GovernanceImpact"]
                    newMet = {
                        "label": "GovernanceImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)


    else:
        pass


"""
Endpoint used to update the custom metrics for renew measurement
"""
@customsroute.post('/custommeasureRe')
async def custom_measure_renew(cmet: RenewMeasure):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "RenewableEnergy":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "RenewableEnergy"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "RenewableEnergy"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "RenewableEnergy"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "energyConsumed": cmet.s1,
                            "renewableConsumed": cmet.s2
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "RenewableEnergy",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "energyConsumed": cmet.s1,
                            "renewableConsumed": cmet.s2
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "RenewableEnergy",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "RenewableEnergy"]
                    newMet = {
                        "label": "RenewableEnergy",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "energyConsumed": cmet.s1,
                                                            "renewableConsumed": cmet.s2
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "DERImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "DERImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "DERImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "DERImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "derQuotes": cmet.s1,
                            "buildingsEvaluated": cmet.s2,
                            "renewableSuppliers": cmet.s3,
                            "derInstallations": cmet.s4,
                            "totalMW": cmet.s7
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "DERImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "derQuotes": cmet.s1,
                            "buildingsEvaluated": cmet.s2,
                            "renewableSuppliers": cmet.s3,
                            "derInstallations": cmet.s4,
                            "totalMW": cmet.s7
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "DERImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "DERImpact"]
                    newMet = {
                        "label": "DERImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "derQuotes": cmet.s1,
                                                            "buildingsEvaluated": cmet.s2,
                                                            "renewableSuppliers": cmet.s3,
                                                            "derInstallations": cmet.s4,
                                                            "totalMW": cmet.s7
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "ImpactEmissions":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "ImpactEmissions"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "ImpactEmissions"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "ImpactEmissions"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "solarVarA": cmet.s1,
                            "sBatteryVarA": cmet.s2,
                            "sBatteryVarB2": cmet.s3,
                            "sBatteryVarC3": cmet.s4
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "ImpactEmissions",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "solarVarA": cmet.s1,
                            "sBatteryVarA": cmet.s2,
                            "sBatteryVarB2": cmet.s3,
                            "sBatteryVarC3": cmet.s4
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "ImpactEmissions",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "ImpactEmissions"]
                    newMet = {
                        "label": "ImpactEmissions",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "solarVarA": cmet.s1,
                                                            "sBatteryVarA": cmet.s2,
                                                            "sBatteryVarB2": cmet.s3,
                                                            "sBatteryVarC3": cmet.s4
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "CompanyImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "CompanyImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "CompanyImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "CompanyImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "carbonOffsettingY": cmet.m1,
                            "sustainabilityStories": cmet.s1,
                            "provideURL": cmet.s2,
                            "carbonTons": cmet.s3,
                            "carbonOffsetting": cmet.s7
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "CompanyImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "carbonOffsettingY": cmet.m1,
                            "sustainabilityStories": cmet.s1,
                            "provideURL": cmet.s2,
                            "carbonTons": cmet.s3,
                            "carbonOffsetting": cmet.s7
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "CompanyImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "CompanyImpact"]
                    newMet = {
                        "label": "CompanyImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "carbonOffsettingY": cmet.m1,
                                                            "sustainabilityStories": cmet.s1,
                                                            "provideURL": cmet.s2,
                                                            "carbonTons": cmet.s3,
                                                            "carbonOffsetting": cmet.s7
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "CorporateGovernance":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "CorporateGovernance"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "CorporateGovernance"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "CorporateGovernance"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "esgPolicyY": cmet.m1,
                            "carbonNeutralY": cmet.m2,
                            "humanRightsY": cmet.m3,
                            "againstCybersecurityY": cmet.m4,
                            "incidentsReportedY": cmet.m5,
                            "esgOversightY": cmet.m6,
                            "whistleBPolicyY": cmet.m7,
                            "waterRisksY": cmet.m8,
                            "ecoSensitiveY": cmet.m9,
                            "kycScreeningY": cmet.m10,
                            "esgMetricsTracked": cmet.s1,
                            "CNTimeline": cmet.s2,
                            "RDexpenditure": cmet.s3,
                            "currencyFrame": cmet.s4,
                            "CpercentageRevenue": cmet.s7,
                            "esgPolicy": cmet.s8,
                            "carbonNeutral": cmet.s9,
                            "humanRights": cmet.s10,
                            "againstCybersecurity": cmet.s11,
                            "incidentsReported": cmet.s12,
                            "esgOversight": cmet.s13,
                            "whistleBPolicy": cmet.s14,
                            "waterRisks": cmet.s15,
                            "ecoSensitive": cmet.s16,
                            "kycScreening": cmet.s17,
                            "decarbonStratYWO": cmet.s18,
                            "decarbonStratY": cmet.s19,
                            "decarbonStratN": cmet.s20,
                            "ghgReductYNP": cmet.s21,
                            "ghgReductYP": cmet.s22,
                            "ghgReductN": cmet.s23,
                            "ltGoalNNP": cmet.s24,
                            "ltGoalNWP": cmet.s25,
                            "ltGoalNLP": cmet.s26,
                            "ltGoalY": cmet.s27
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "CorporateGovernance",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "esgPolicyY": cmet.m1,
                            "carbonNeutralY": cmet.m2,
                            "humanRightsY": cmet.m3,
                            "againstCybersecurityY": cmet.m4,
                            "incidentsReportedY": cmet.m5,
                            "esgOversightY": cmet.m6,
                            "whistleBPolicyY": cmet.m7,
                            "waterRisksY": cmet.m8,
                            "ecoSensitiveY": cmet.m9,
                            "kycScreeningY": cmet.m10,
                            "esgMetricsTracked": cmet.s1,
                            "CNTimeline": cmet.s2,
                            "RDexpenditure": cmet.s3,
                            "currencyFrame": cmet.s4,
                            "CpercentageRevenue": cmet.s7,
                            "esgPolicy": cmet.s8,
                            "carbonNeutral": cmet.s9,
                            "humanRights": cmet.s10,
                            "againstCybersecurity": cmet.s11,
                            "incidentsReported": cmet.s12,
                            "esgOversight": cmet.s13,
                            "whistleBPolicy": cmet.s14,
                            "waterRisks": cmet.s15,
                            "ecoSensitive": cmet.s16,
                            "kycScreening": cmet.s17,
                            "decarbonStratYWO": cmet.s18,
                            "decarbonStratY": cmet.s19,
                            "decarbonStratN": cmet.s20,
                            "ghgReductYNP": cmet.s21,
                            "ghgReductYP": cmet.s22,
                            "ghgReductN": cmet.s23,
                            "ltGoalNNP": cmet.s24,
                            "ltGoalNWP": cmet.s25,
                            "ltGoalNLP": cmet.s26,
                            "ltGoalY": cmet.s27
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "CorporateGovernance",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "CorporateGovernance"]
                    newMet = {
                        "label": "CorporateGovernance",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "esgPolicyY": cmet.m1,
                                                            "carbonNeutralY": cmet.m2,
                                                            "humanRightsY": cmet.m3,
                                                            "againstCybersecurityY": cmet.m4,
                                                            "incidentsReportedY": cmet.m5,
                                                            "esgOversightY": cmet.m6,
                                                            "whistleBPolicyY": cmet.m7,
                                                            "waterRisksY": cmet.m8,
                                                            "ecoSensitiveY": cmet.m9,
                                                            "kycScreeningY": cmet.m10,
                                                            "esgMetricsTracked": cmet.s1,
                                                            "CNTimeline": cmet.s2,
                                                            "RDexpenditure": cmet.s3,
                                                            "currencyFrame": cmet.s4,
                                                            "CpercentageRevenue": cmet.s7,
                                                            "esgPolicy": cmet.s8,
                                                            "carbonNeutral": cmet.s9,
                                                            "humanRights": cmet.s10,
                                                            "againstCybersecurity": cmet.s11,
                                                            "incidentsReported": cmet.s12,
                                                            "esgOversight": cmet.s13,
                                                            "whistleBPolicy": cmet.s14,
                                                            "waterRisks": cmet.s15,
                                                            "ecoSensitive": cmet.s16,
                                                            "kycScreening": cmet.s17,
                                                            "decarbonStratYWO": cmet.s18,
                                                            "decarbonStratY": cmet.s19,
                                                            "decarbonStratN": cmet.s20,
                                                            "ghgReductYNP": cmet.s21,
                                                            "ghgReductYP": cmet.s22,
                                                            "ghgReductN": cmet.s23,
                                                            "ltGoalNNP": cmet.s24,
                                                            "ltGoalNWP": cmet.s25,
                                                            "ltGoalNLP": cmet.s26,
                                                            "ltGoalY": cmet.s27
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "EnvironmentalImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "EnvironmentalImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "EnvironmentalImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "EnvironmentalImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "chiaQ": cmet.s1,
                            "chiaUnit": cmet.s2,
                            "cashewsQ": cmet.s3,
                            "cashewsUnit": cmet.s4,
                            "raisinsQ": cmet.s7,
                            "raisinsUnit": cmet.s8,
                            "cranberriesQ": cmet.s9,
                            "cranberriesUnit": cmet.s10,
                            "almondsQ": cmet.s11,
                            "almondsUnit": cmet.s12,
                            "walnutsQ": cmet.s13,
                            "walnutsUnit": cmet.s14,
                            "organicPc": cmet.s15
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "chiaQ": cmet.s1,
                            "chiaUnit": cmet.s2,
                            "cashewsQ": cmet.s3,
                            "cashewsUnit": cmet.s4,
                            "raisinsQ": cmet.s7,
                            "raisinsUnit": cmet.s8,
                            "cranberriesQ": cmet.s9,
                            "cranberriesUnit": cmet.s10,
                            "almondsQ": cmet.s11,
                            "almondsUnit": cmet.s12,
                            "walnutsQ": cmet.s13,
                            "walnutsUnit": cmet.s14,
                            "organicPc": cmet.s15
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "EnvironmentalImpact"]
                    newMet = {
                        "label": "EnvironmentalImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "chiaQ": cmet.s1,
                                                            "chiaUnit": cmet.s2,
                                                            "cashewsQ": cmet.s3,
                                                            "cashewsUnit": cmet.s4,
                                                            "raisinsQ": cmet.s7,
                                                            "raisinsUnit": cmet.s8,
                                                            "cranberriesQ": cmet.s9,
                                                            "cranberriesUnit": cmet.s10,
                                                            "almondsQ": cmet.s11,
                                                            "almondsUnit": cmet.s12,
                                                            "walnutsQ": cmet.s13,
                                                            "walnutsUnit": cmet.s14,
                                                            "organicPc": cmet.s15
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "CabooImpactMeasurement":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "CabooImpactMeasurement"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "CabooImpactMeasurement"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "CabooImpactMeasurement"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14,
                            "var13": cmet.s15,
                            "var14": cmet.s16,
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "CabooImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14,
                            "var13": cmet.s15,
                            "var14": cmet.s16,
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "CabooImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "CabooImpactMeasurement"]
                    newMet = {
                        "label": "CabooImpactMeasurement",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9,
                                                            "var8": cmet.s10,
                                                            "var9": cmet.s11,
                                                            "var10": cmet.s12,
                                                            "var11": cmet.s13,
                                                            "var12": cmet.s14,
                                                            "var13": cmet.s15,
                                                            "var14": cmet.s16,
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "HolosImpactMeasurement":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "HolosImpactMeasurement"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "HolosImpactMeasurement"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "HolosImpactMeasurement"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "HolosImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "HolosImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "HolosImpactMeasurement"]
                    newMet = {
                        "label": "HolosImpactMeasurement",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9,
                                                            "var8": cmet.s10,
                                                            "var9": cmet.s11,
                                                            "var10": cmet.s12,
                                                            "var11": cmet.s13,
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "LacunaImpactMeasurement":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "LacunaImpactMeasurement"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "LacunaImpactMeasurement"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "LacunaImpactMeasurement"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "LacunaImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "LacunaImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "LacunaImpactMeasurement"]
                    newMet = {
                        "label": "LacunaImpactMeasurement",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "MattsImpactMeasurement":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "MattsImpactMeasurement"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "MattsImpactMeasurement"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "MattsImpactMeasurement"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "MattsImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "MattsImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "MattsImpactMeasurement"]
                    newMet = {
                        "label": "MattsImpactMeasurement",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "OleaImpactMeasurement":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "OleaImpactMeasurement"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "OleaImpactMeasurement"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "OleaImpactMeasurement"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "var1": cmet.s1,
                            "var2": cmet.s2
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "OleaImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "var1": cmet.s1,
                            "var2": cmet.s2
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "OleaImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "OleaImpactMeasurement"]
                    newMet = {
                        "label": "OleaImpactMeasurement",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "TruEarthImpactMeasurement":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "TruEarthImpactMeasurement"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "TruEarthImpactMeasurement"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "TruEarthImpactMeasurement"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14,
                            "var13": cmet.s15
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "TruEarthImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14,
                            "var13": cmet.s15
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "TruEarthImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "TruEarthImpactMeasurement"]
                    newMet = {
                        "label": "TruEarthImpactMeasurement",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9,
                                                            "var8": cmet.s10,
                                                            "var9": cmet.s11,
                                                            "var10": cmet.s12,
                                                            "var11": cmet.s13,  
                                                            "var12": cmet.s14,
                                                            "var13": cmet.s15
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "FreshPrepImpactMeasurement":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "FreshPrepImpactMeasurement"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "FreshPrepImpactMeasurement"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "FreshPrepImpactMeasurement"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "FreshPrepImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "FreshPrepImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "FreshPrepImpactMeasurement"]
                    newMet = {
                        "label": "FreshPrepImpactMeasurement",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9,
                                                            "var8": cmet.s10
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "SwiftlyImpactMeasurement":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "SwiftlyImpactMeasurement"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "SwiftlyImpactMeasurement"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "SwiftlyImpactMeasurement"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "SwiftlyImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "SwiftlyImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "SwiftlyImpactMeasurement"]
                    newMet = {
                        "label": "SwiftlyImpactMeasurement",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "EviveImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "EviveImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "EviveImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "EviveImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bananasQ": cmet.s1,
                            "strawberriesQ": cmet.s2,
                            "mangoesQ": cmet.s3,
                            "pineappleQ": cmet.s4,
                            "blueberriesQ": cmet.s7,
                            "peaQ": cmet.s8,
                            "pearsQ": cmet.s9,
                            "applesQ": cmet.s10,
                            "bananasUnit": cmet.s11,
                            "strawberriesUnit": cmet.s12,
                            "mangoesUnit": cmet.s13,
                            "pineappleUnit": cmet.s14,
                            "blueberriesUnit": cmet.s15,
                            "peaUnit": cmet.s16,
                            "pearsUnit": cmet.s17,
                            "applesUnit": cmet.s18,
                            "organicPc": cmet.s19,
                            "treesPlanted": cmet.s20,
                            "treesDOM": cmet.s21,
                            "totalWeight": cmet.s22,
                            "totalWeightDOM": cmet.s23,
                            "packaging": cmet.s24
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "EviveImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bananasQ": cmet.s1,
                            "strawberriesQ": cmet.s2,
                            "mangoesQ": cmet.s3,
                            "pineappleQ": cmet.s4,
                            "blueberriesQ": cmet.s7,
                            "peaQ": cmet.s8,
                            "pearsQ": cmet.s9,
                            "applesQ": cmet.s10,
                            "bananasUnit": cmet.s11,
                            "strawberriesUnit": cmet.s12,
                            "mangoesUnit": cmet.s13,
                            "pineappleUnit": cmet.s14,
                            "blueberriesUnit": cmet.s15,
                            "peaUnit": cmet.s16,
                            "pearsUnit": cmet.s17,
                            "applesUnit": cmet.s18,
                            "organicPc": cmet.s19,
                            "treesPlanted": cmet.s20,
                            "treesDOM": cmet.s21,
                            "totalWeight": cmet.s22,
                            "totalWeightDOM": cmet.s23,
                            "packaging": cmet.s24
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "EviveImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "EviveImpact"]
                    newMet = {
                        "label": "EviveImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bananasQ": cmet.s1,
                                                            "strawberriesQ": cmet.s2,
                                                            "mangoesQ": cmet.s3,
                                                            "pineappleQ": cmet.s4,
                                                            "blueberriesQ": cmet.s7,
                                                            "peaQ": cmet.s8,
                                                            "pearsQ": cmet.s9,
                                                            "applesQ": cmet.s10,
                                                            "bananasUnit": cmet.s11,
                                                            "strawberriesUnit": cmet.s12,
                                                            "mangoesUnit": cmet.s13,
                                                            "pineappleUnit": cmet.s14,
                                                            "blueberriesUnit": cmet.s15,
                                                            "peaUnit": cmet.s16,
                                                            "pearsUnit": cmet.s17,
                                                            "applesUnit": cmet.s18,
                                                            "organicPc": cmet.s19,
                                                            "treesPlanted": cmet.s20,
                                                            "treesDOM": cmet.s21,
                                                            "totalWeight": cmet.s22,
                                                            "totalWeightDOM": cmet.s23,
                                                            "packaging": cmet.s24
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "ElectrumImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "ElectrumImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "ElectrumImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "ElectrumImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s49,
                            "var6": cmet.s50,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s11,
                            "var12": cmet.s12,
                            "var13": cmet.s13,
                            "var14": cmet.s14,
                            "var15": cmet.s15,
                            "var16": cmet.s16,
                            "var17": cmet.s17,
                            "var18": cmet.s18,
                            "var19": cmet.s19,
                            "var20": cmet.s20,
                            "var21": cmet.s21,
                            "var22": cmet.s22,
                            "var23": cmet.s23,
                            "var24": cmet.s24,
                            "var25": cmet.s25,
                            "var26": cmet.s26,
                            "var27": cmet.s27,
                            "var28": cmet.s28,
                            "var29": cmet.s29,
                            "var30": cmet.s30,
                            "var31": cmet.s31,
                            "var32": cmet.s32,
                            "var33": cmet.s33,
                            "var34": cmet.s34,
                            "var35": cmet.s35,
                            "var36": cmet.s36,
                            "var37": cmet.s37,
                            "var38": cmet.s38,
                            "var39": cmet.s39,
                            "var40": cmet.s40,
                            "var41": cmet.s41,
                            "var42": cmet.s42,
                            "var43": cmet.s43,
                            "var44": cmet.s44,
                            "var45": cmet.s45,
                            "var46": cmet.s46,
                            "var47": cmet.s47,
                            "var48": cmet.s48
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "ElectrumImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s49,
                            "var6": cmet.s50,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s11,
                            "var12": cmet.s12,
                            "var13": cmet.s13,
                            "var14": cmet.s14,
                            "var15": cmet.s15,
                            "var16": cmet.s16,
                            "var17": cmet.s17,
                            "var18": cmet.s18,
                            "var19": cmet.s19,
                            "var20": cmet.s20,
                            "var21": cmet.s21,
                            "var22": cmet.s22,
                            "var23": cmet.s23,
                            "var24": cmet.s24,
                            "var25": cmet.s25,
                            "var26": cmet.s26,
                            "var27": cmet.s27,
                            "var28": cmet.s28,
                            "var29": cmet.s29,
                            "var30": cmet.s30,
                            "var31": cmet.s31,
                            "var32": cmet.s32,
                            "var33": cmet.s33,
                            "var34": cmet.s34,
                            "var35": cmet.s35,
                            "var36": cmet.s36,
                            "var37": cmet.s37,
                            "var38": cmet.s38,
                            "var39": cmet.s39,
                            "var40": cmet.s40,
                            "var41": cmet.s41,
                            "var42": cmet.s42,
                            "var43": cmet.s43,
                            "var44": cmet.s44,
                            "var45": cmet.s45,
                            "var46": cmet.s46,
                            "var47": cmet.s47,
                            "var48": cmet.s48
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "ElectrumImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "ElectrumImpact"]
                    newMet = {
                        "label": "ElectrumImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s49,
                                                            "var6": cmet.s50,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s11,
                                                            "var12": cmet.s12,
                                                            "var13": cmet.s13,
                                                            "var14": cmet.s14,
                                                            "var15": cmet.s15,
                                                            "var16": cmet.s16,
                                                            "var17": cmet.s17,
                                                            "var18": cmet.s18,
                                                            "var19": cmet.s19,
                                                            "var20": cmet.s20,
                                                            "var21": cmet.s21,
                                                            "var22": cmet.s22,
                                                            "var23": cmet.s23,
                                                            "var24": cmet.s24,
                                                            "var25": cmet.s25,
                                                            "var26": cmet.s26,
                                                            "var27": cmet.s27,
                                                            "var28": cmet.s28,
                                                            "var29": cmet.s29,
                                                            "var30": cmet.s30,
                                                            "var31": cmet.s31,
                                                            "var32": cmet.s32,
                                                            "var33": cmet.s33,
                                                            "var34": cmet.s34,
                                                            "var35": cmet.s35,
                                                            "var36": cmet.s36,
                                                            "var37": cmet.s37,
                                                            "var38": cmet.s38,
                                                            "var39": cmet.s39,
                                                            "var40": cmet.s40,
                                                            "var41": cmet.s41,
                                                            "var42": cmet.s42,
                                                            "var43": cmet.s43,
                                                            "var44": cmet.s44,
                                                            "var45": cmet.s45,
                                                            "var46": cmet.s46,
                                                            "var47": cmet.s47,
                                                            "var48": cmet.s48
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "HodoImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "HodoImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "HodoImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "HodoImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "soyQ": cmet.s1,
                            "soyUnit": cmet.s2,
                            "organicPc": cmet.s3
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "HodoImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "soyQ": cmet.s1,
                            "soyUnit": cmet.s2,
                            "organicPc": cmet.s3
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "HodoImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "HodoImpact"]
                    newMet = {
                        "label": "HodoImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "soyQ": cmet.s1,
                                                            "soyUnit": cmet.s2,
                                                            "organicPc": cmet.s3
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "ShareMobilityImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "ShareMobilityImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "ShareMobilityImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "ShareMobilityImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "ShareMobilityImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "ShareMobilityImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "ShareMobilityImpact"]
                    newMet = {
                        "label": "ShareMobilityImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "ImpactQuestionnaire":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "ImpactQuestionnaire"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "ImpactQuestionnaire"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "ImpactQuestionnaire"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "impact-measurement": cmet.s1,
                            "energy-consumption": cmet.s2,
                            "company-impact": cmet.s3,
                            "corporate-governance": cmet.s4,
                            "corporate-diversity": cmet.s7,
                            "work-related-accidents": cmet.s8,
                            "employee-engagement": cmet.s9,
                            "scope-1-emissions": cmet.s10,
                            "scope-2-emission": cmet.s11,
                            "scope-2-electricity": cmet.s12,
                            "scope-2-heat-and-steam": cmet.s13,
                            "scope-2-remote-workers": cmet.s14,
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "ImpactQuestionnaire",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "impact-measurement": cmet.s1,
                            "energy-consumption": cmet.s2,
                            "company-impact": cmet.s3,
                            "corporate-governance": cmet.s4,
                            "corporate-diversity": cmet.s7,
                            "work-related-accidents": cmet.s8,
                            "employee-engagement": cmet.s9,
                            "scope-1-emissions": cmet.s10,
                            "scope-2-emission": cmet.s11,
                            "scope-2-electricity": cmet.s12,
                            "scope-2-heat-and-steam": cmet.s13,
                            "scope-2-remote-workers": cmet.s14,
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "ImpactQuestionnaire",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "ImpactQuestionnaire"]
                    newMet = {
                        "label": "ImpactQuestionnaire",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "impact-measurement": cmet.s1,
                                                            "energy-consumption": cmet.s2,
                                                            "company-impact": cmet.s3,
                                                            "corporate-governance": cmet.s4,
                                                            "corporate-diversity": cmet.s7,
                                                            "work-related-accidents": cmet.s8,
                                                            "employee-engagement": cmet.s9,
                                                            "scope-1-emissions": cmet.s10,
                                                            "scope-2-emission": cmet.s11,
                                                            "scope-2-electricity": cmet.s12,
                                                            "scope-2-heat-and-steam": cmet.s13,
                                                            "scope-2-remote-workers": cmet.s14,
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "EmployeeRelations":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "EmployeeRelations"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "EmployeeRelations"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "EmployeeRelations"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "engagementSurveysY": cmet.m1,
                            "workInjuries": cmet.s1,
                            "workFatalities": cmet.s2,
                            "daysLost": cmet.s3,
                            "percentageEmployees": cmet.s4
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "EmployeeRelations",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "engagementSurveysY": cmet.m1,
                            "workInjuries": cmet.s1,
                            "workFatalities": cmet.s2,
                            "daysLost": cmet.s3,
                            "percentageEmployees": cmet.s4
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "EmployeeRelations",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "EmployeeRelations"]
                    newMet = {
                        "label": "EmployeeRelations",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "engagementSurveysY": cmet.m1,
                                                            "workInjuries": cmet.s1,
                                                            "workFatalities": cmet.s2,
                                                            "daysLost": cmet.s3,
                                                            "percentageEmployees": cmet.s4
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

    else:
        pass


"""
Endpoint used to update the custom metrics for Quona measurement
"""
@customsroute.post('/custommeasureQuona')
async def custom_measure_quona(cmet: QuonaMeasure):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "EnvironmentalImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "EnvironmentalImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "EnvironmentalImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "EnvironmentalImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22,
                            "varbool13": cmet.s23,
                            "varbool14": cmet.s24
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22,
                            "varbool13": cmet.s23,
                            "varbool14": cmet.s24
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "EnvironmentalImpact"]
                    newMet = {
                        "label": "EnvironmentalImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31,
                                                            "varbool1": cmet.s11,
                                                            "varbool2": cmet.s12,
                                                            "varbool3": cmet.s13,
                                                            "varbool4": cmet.s14,
                                                            "varbool5": cmet.s15,
                                                            "varbool6": cmet.s16,
                                                            "varbool7": cmet.s17,
                                                            "varbool8": cmet.s18,
                                                            "varbool9": cmet.s19,
                                                            "varbool10": cmet.s20,
                                                            "varbool11": cmet.s21,
                                                            "varbool12": cmet.s22,
                                                            "varbool13": cmet.s23,
                                                            "varbool14": cmet.s24
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "GovernanceImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "GovernanceImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "GovernanceImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "GovernanceImpact"]
                    newMet = {
                        "label": "GovernanceImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31,
                                                            "varbool1": cmet.s11,
                                                            "varbool2": cmet.s12,
                                                            "varbool3": cmet.s13,
                                                            "varbool4": cmet.s14,
                                                            "varbool5": cmet.s15,
                                                            "varbool6": cmet.s16,
                                                            "varbool7": cmet.s17,
                                                            "varbool8": cmet.s18,
                                                            "varbool9": cmet.s19,
                                                            "varbool10": cmet.s20,
                                                            "varbool11": cmet.s21,
                                                            "varbool12": cmet.s22
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "SocialImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "SocialImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "SocialImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "SocialImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22,
                            "varbool13": cmet.s23,
                            "varbool14": cmet.s24,
                            "varbool15": cmet.s25,
                            "varbool16": cmet.s26
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22,
                            "varbool13": cmet.s23,
                            "varbool14": cmet.s24,
                            "varbool15": cmet.s25,
                            "varbool16": cmet.s26
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "SocialImpact"]
                    newMet = {
                        "label": "SocialImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31,
                                                            "varbool1": cmet.s11,
                                                            "varbool2": cmet.s12,
                                                            "varbool3": cmet.s13,
                                                            "varbool4": cmet.s14,
                                                            "varbool5": cmet.s15,
                                                            "varbool6": cmet.s16,
                                                            "varbool7": cmet.s17,
                                                            "varbool8": cmet.s18,
                                                            "varbool9": cmet.s19,
                                                            "varbool10": cmet.s20,
                                                            "varbool11": cmet.s21,
                                                            "varbool12": cmet.s22,
                                                            "varbool13": cmet.s23,
                                                            "varbool14": cmet.s24,
                                                            "varbool15": cmet.s25,
                                                            "varbool16": cmet.s26
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "ImpactMeasure":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "ImpactMeasure"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "ImpactMeasure"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "ImpactMeasure"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "bool1": cmet.m1,
                            "bool3": cmet.m3
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "ImpactMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "bool1": cmet.m1,
                            "bool3": cmet.m3
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "ImpactMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "ImpactMeasure"]
                    newMet = {
                        "label": "ImpactMeasure",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "bool1": cmet.m1,
                                                            "bool3": cmet.m3
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "FinalPage":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "FinalPage"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "FinalPage"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "FinalPage"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "esgAnswer": cmet.m1,
                            "firstName": cmet.s1,
                            "lastName": cmet.s2
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "FinalPage",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "esgAnswer": cmet.m1,
                            "firstName": cmet.s1,
                            "lastName": cmet.s2
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "FinalPage",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "FinalPage"]
                    newMet = {
                        "label": "FinalPage",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "esgAnswer": cmet.m1,
                                                            "firstName": cmet.s1,
                                                            "lastName": cmet.s2
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "QuonaImpactQuestionnaireProgress":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [_item for _item in db_resultC["carbonmeasure"]
                              if _item["label"] != "Emissions"]

                    if ([_item for _item in db_resultC["carbonmeasure"] if _item["label"] == "Emissions"]):
                        emData = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] == "Emissions"][0]

                        if ([_item for _item in emData["metrics"] if _item["label"] == cmet.s5]):
                            yearData2C = [
                                _item for _item in emData["metrics"] if _item["label"] == cmet.s5][0]
                            if ([_item for _item in yearData2C["value"] if _item["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    _item for _item in yearData2C["value"] if _item["label"] != cmet.s6]
                                customMeasurement2C = []
                                customMeasurement2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [_item for _item in emData["metrics"]
                                           if _item["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            customMeasurement2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [_item for _item in emData["metrics"]
                                       if _item["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": customMeasurement2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [_item for _item in db_result["custommeasure"] if _item["label"] != "QuonaImpactQuestionnaireProgress"]

                if ([_item for _item in db_result["custommeasure"] if _item["label"] == "QuonaImpactQuestionnaireProgress"]):
                    remoteData = [_item for _item in db_result["custommeasure"] if _item["label"] == "QuonaImpactQuestionnaireProgress"][0]
                    if ([_item for _item in remoteData["metrics"] if _item["label"] == cmet.s5]):
                        yearData = [_item for _item in remoteData["metrics"]
                                    if _item["label"] == cmet.s5][0]
                        quarterData = [
                            _item for _item in yearData["value"] if _item["label"] != cmet.s6]
                        customMeasurement = []
                        customMeasurement.append({
                            'esg-management': cmet.s1,
                            'environmental-management': cmet.s2,
                            'water-and-waste': cmet.s3,
                            'ghg-emission': cmet.s4,
                            "diversity-and-inclusion": cmet.s7,
                            "pay-equality": cmet.s8,
                            "employment": cmet.s9,
                            "employee-engagement": cmet.s10,
                            "skill-development": cmet.s11,
                            "health-and-safety": cmet.s12,
                            "human-rights": cmet.s13,
                            "board-composition": cmet.s14,
                            "anti-corruption": cmet.s15,
                            "data-security": cmet.s16,
                            "business-ethics": cmet.s17,
                            "supply-chain": cmet.s18,
                            "achievements-2022": cmet.s19,
                            "goals-2023": cmet.s20,
                            "environmental-impact": cmet.s21,
                            "scope-1-emissions": cmet.s22,
                            "scope-2-emissions": cmet.s23,
                            "scope-3-emissions": cmet.s24,
                        })
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": customMeasurement
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "QuonaImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        customMeasurement = [{
                            'esg-management': cmet.s1,
                            'environmental-management': cmet.s2,
                            'water-and-waste': cmet.s3,
                            'ghg-emission': cmet.s4,
                            "diversity-and-inclusion": cmet.s7,
                            "pay-equality": cmet.s8,
                            "employment": cmet.s9,
                            "employee-engagement": cmet.s10,
                            "skill-development": cmet.s11,
                            "health-and-safety": cmet.s12,
                            "human-rights": cmet.s13,
                            "board-composition": cmet.s14,
                            "anti-corruption": cmet.s15,
                            "data-security": cmet.s16,
                            "business-ethics": cmet.s17,
                            "supply-chain": cmet.s18,
                            "achievements-2022": cmet.s19,
                            "goals-2023": cmet.s20,
                            "environmental-impact": cmet.s21,
                            "scope-1-emissions": cmet.s22,
                            "scope-2-emissions": cmet.s23,
                            "scope-3-emissions": cmet.s24,
                        }]
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "QuonaImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [_item for _item in db_result["custommeasure"]
                            if _item["label"] != "QuonaImpactQuestionnaireProgress"]
                    newMet = {
                        "label": "QuonaImpactQuestionnaireProgress",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            'esg-management': cmet.s1,
                                                            'environmental-management': cmet.s2,
                                                            'water-and-waste': cmet.s3,
                                                            'ghg-emission': cmet.s4,
                                                            "diversity-and-inclusion": cmet.s7,
                                                            "pay-equality": cmet.s8,
                                                            "employment": cmet.s9,
                                                            "employee-engagement": cmet.s10,
                                                            "skill-development": cmet.s11,
                                                            "health-and-safety": cmet.s12,
                                                            "human-rights": cmet.s13,
                                                            "board-composition": cmet.s14,
                                                            "anti-corruption": cmet.s15,
                                                            "data-security": cmet.s16,
                                                            "business-ethics": cmet.s17,
                                                            "supply-chain": cmet.s18,
                                                            "achievements-2022": cmet.s19,
                                                            "goals-2023": cmet.s20,
                                                            "environmental-impact": cmet.s21,
                                                            "scope-1-emissions": cmet.s22,
                                                            "scope-2-emissions": cmet.s23,
                                                            "scope-3-emi,ssions": cmet.s24
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

    else:
        pass



"""
Endpoint used to update the custom metrics for Quona measurement
"""
@customsroute.post('/custommeasureGobi')
async def custom_measure_quona(cmet: QuonaMeasure):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "EnvironmentalImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "EnvironmentalImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "EnvironmentalImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "EnvironmentalImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22,
                            "varbool13": cmet.s23,
                            "varbool14": cmet.s24
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22,
                            "varbool13": cmet.s23,
                            "varbool14": cmet.s24
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "EnvironmentalImpact"]
                    newMet = {
                        "label": "EnvironmentalImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31,
                                                            "varbool1": cmet.s11,
                                                            "varbool2": cmet.s12,
                                                            "varbool3": cmet.s13,
                                                            "varbool4": cmet.s14,
                                                            "varbool5": cmet.s15,
                                                            "varbool6": cmet.s16,
                                                            "varbool7": cmet.s17,
                                                            "varbool8": cmet.s18,
                                                            "varbool9": cmet.s19,
                                                            "varbool10": cmet.s20,
                                                            "varbool11": cmet.s21,
                                                            "varbool12": cmet.s22,
                                                            "varbool13": cmet.s23,
                                                            "varbool14": cmet.s24
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "GovernanceImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "GovernanceImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "GovernanceImpact"]
                    newMet = {
                        "label": "GovernanceImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "SocialImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "SocialImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "SocialImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "SocialImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "SocialImpact"]
                    newMet = {
                        "label": "SocialImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "GobiImpactQuestionnaireProgress":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [_item for _item in db_resultC["carbonmeasure"]
                              if _item["label"] != "Emissions"]

                    if ([_item for _item in db_resultC["carbonmeasure"] if _item["label"] == "Emissions"]):
                        emData = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] == "Emissions"][0]

                        if ([_item for _item in emData["metrics"] if _item["label"] == cmet.s5]):
                            yearData2C = [
                                _item for _item in emData["metrics"] if _item["label"] == cmet.s5][0]
                            if ([_item for _item in yearData2C["value"] if _item["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    _item for _item in yearData2C["value"] if _item["label"] != cmet.s6]
                                customMeasurement2C = []
                                customMeasurement2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [_item for _item in emData["metrics"]
                                           if _item["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            customMeasurement2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [_item for _item in emData["metrics"]
                                       if _item["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": customMeasurement2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [_item for _item in db_result["custommeasure"] if _item["label"] != "GobiImpactQuestionnaireProgress"]

                if ([_item for _item in db_result["custommeasure"] if _item["label"] == "GobiImpactQuestionnaireProgress"]):
                    remoteData = [_item for _item in db_result["custommeasure"] if _item["label"] == "GobiImpactQuestionnaireProgress"][0]
                    if ([_item for _item in remoteData["metrics"] if _item["label"] == cmet.s5]):
                        yearData = [_item for _item in remoteData["metrics"] if _item["label"] == cmet.s5][0]
                        quarterData = [_item for _item in yearData["value"] if _item["label"] != cmet.s6]
                        customMeasurement = []
                        customMeasurement.append({
                            'scope-1-emissions': cmet.s1,
                            'scope-2-emissions': cmet.s2,
                            'scope-3-emissions': cmet.s3,
                            'employee-overview': cmet.s4,
                            "health-and-safety": cmet.s7,
                            "gender-diversity": cmet.s8,
                            "board-structure": cmet.s9,
                            "corporate-policy": cmet.s10,
                            "scope-2-remote-workers": cmet.s11,
                            "scope-2-electricity": cmet.s12,
                            "scope-2-heat-and-steam": cmet.s13,
                            "scope-3-travel": cmet.s14,
                            "scope-3-commuting": cmet.s15,
                            "scope-3-cloud": cmet.s16
                        })
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": customMeasurement
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GobiImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        customMeasurement = [{
                            'scope-1-emissions': cmet.s1,
                            'scope-2-emissions': cmet.s2,
                            'scope-3-emissions': cmet.s3,
                            'employee-overview': cmet.s4,
                            "health-and-safety": cmet.s7,
                            "gender-diversity": cmet.s8,
                            "board-structure": cmet.s9,
                            "corporate-policy": cmet.s10,
                            "scope-2-remote-workers": cmet.s11,
                            "scope-2-electricity": cmet.s12,
                            "scope-2-heat-and-steam": cmet.s13,
                            "scope-3-travel": cmet.s14,
                            "scope-3-commuting": cmet.s15,
                            "scope-3-cloud": cmet.s16
                        }]
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GobiImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [_item for _item in db_result["custommeasure"]
                            if _item["label"] != "GobiImpactQuestionnaireProgress"]
                    newMet = {
                        "label": "GobiImpactQuestionnaireProgress",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                           'scope-1-emissions': cmet.s1,
                                                            'scope-2-emissions': cmet.s2,
                                                            'scope-3-emissions': cmet.s3,
                                                            'employee-overview': cmet.s4,
                                                            "health-and-safety": cmet.s7,
                                                            "gender-diversity": cmet.s8,
                                                            "board-structure": cmet.s9,
                                                            "corporate-policy": cmet.s10,
                                                            "scope-2-remote-workers": cmet.s11,
                                                            "scope-2-electricity": cmet.s12,
                                                            "scope-2-heat-and-steam": cmet.s13,
                                                            "scope-3-travel": cmet.s14,
                                                            "scope-3-commuting": cmet.s15,
                                                            "scope-3-cloud": cmet.s16
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "CorporateImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "CorporateImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "CorporateImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "CorporateImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "CorporateImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "CorporateImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "CorporateImpact"]
                    newMet = {
                        "label": "CorporateImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

    else:
        pass


"""
Endppoint use to add rows to the GobiPage
"""
@customsroute.post('/custommeasureGobiRows')
async def gobi_measure_rows(cmet: CarbonMeasure):
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        return {"url": "/", "atype": False}
    

    if "custommeasure" in db_result:
        if cmet.metric == "CorporateImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s7

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s8

            mets = [z for z in db_result["custommeasure"] if z["label"] != "CorporateImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "CorporateImpact"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "CorporateImpact"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    else:
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "contract": cmet.s1,
                        "funder": cmet.s2,
                        "customer": cmet.s3,
                        "countries": cmet.s11,
                        "sales": cmet.s5
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "CorporateImpact",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in remoteData["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                            cmeas.append({
                                "contract": cmet.s1,
                                "funder": cmet.s2,
                                "customer": cmet.s3,
                                "countries": cmet.s11,
                                "sales": cmet.s5
                            })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                        quarterData2 = []
                        quarterData2.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData2
                        })
                        newMet = {
                            "label": "CorporateImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)   
                    else:
                        cmeas = [{
                            "contract": cmet.s1,
                            "funder": cmet.s2,
                            "customer": cmet.s3,
                            "countries": cmet.s11,
                            "sales": cmet.s5
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                        tmeas.append({
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "CorporateImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "CorporateImpact"]
                newMet = {
                    "label": "CorporateImpact",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "contract": cmet.s1,
                                                        "funder": cmet.s2,
                                                        "customer": cmet.s3,
                                                        "countries": cmet.s11,
                                                        "sales": cmet.s5
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "PatientVolume":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s7

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s8

            mets = [z for z in db_result["custommeasure"] if z["label"] != "PatientVolume"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "PatientVolume"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "PatientVolume"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    else:
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "highbirth": cmet.s1,
                        "mediumbirth": cmet.s2,
                        "lowbirth": cmet.s3
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "PatientVolume",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in remoteData["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                            cmeas.append({
                                "highbirth": cmet.s1,
                                "mediumbirth": cmet.s2,
                                "lowbirth": cmet.s3
                            })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                        quarterData2 = []
                        quarterData2.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData2
                        })
                        newMet = {
                            "label": "PatientVolume",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)   
                    else:
                        cmeas = [{
                            "highbirth": cmet.s1,
                            "mediumbirth": cmet.s2,
                            "lowbirth": cmet.s3
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                        tmeas.append({
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "PatientVolume",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "PatientVolume"]
                newMet = {
                    "label": "PatientVolume",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "highbirth": cmet.s1,
                                                        "mediumbirth": cmet.s2,
                                                        "lowbirth": cmet.s3
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "ProgramImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s7

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s8

            mets = [z for z in db_result["custommeasure"] if z["label"] != "ProgramImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "ProgramImpact"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "ProgramImpact"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    else:
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "program": cmet.s1,
                        "funder": cmet.s2,
                        "countries": cmet.s3,
                        "healthfocus": cmet.s4,
                        "improvement": cmet.s5
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s7,
                        "value": quarterData
                    })
                    newMet = {
                        "label": "ProgramImpact",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in remoteData["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                            cmeas.append({
                                "program": cmet.s1,
                                "funder": cmet.s2,
                                "countries": cmet.s3,
                                "healthfocus": cmet.s4,
                                "improvement": cmet.s5
                            })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                        quarterData2 = []
                        quarterData2.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData2
                        })
                        newMet = {
                            "label": "ProgramImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)   
                    else:
                        cmeas = [{
                            "program": cmet.s1,
                            "funder": cmet.s2,
                            "countries": cmet.s3,
                            "healthfocus": cmet.s4,
                            "improvement": cmet.s5
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                        tmeas.append({
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "ProgramImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "ProgramImpact"]
                newMet = {
                    "label": "ProgramImpact",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "program": cmet.s1,
                                                        "funder": cmet.s2,
                                                        "countries": cmet.s3,
                                                        "healthfocus": cmet.s4,
                                                        "improvement": cmet.s5
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "ProgramImpact2":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s7

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s8

            mets = [z for z in db_result["custommeasure"] if z["label"] != "ProgramImpact2"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "ProgramImpact2"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "ProgramImpact2"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    else:
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "program": cmet.s1,
                        "funder": cmet.s2,
                        "countries": cmet.s3,
                        "healthfocus": cmet.s4,
                        "improvement": cmet.s5
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s7,
                        "value": quarterData
                    })
                    newMet = {
                        "label": "ProgramImpact2",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in remoteData["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                            cmeas.append({
                                "program": cmet.s1,
                                "funder": cmet.s2,
                                "countries": cmet.s3,
                                "healthfocus": cmet.s4,
                                "improvement": cmet.s5
                            })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                        quarterData2 = []
                        quarterData2.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData2
                        })
                        newMet = {
                            "label": "ProgramImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)   
                    else:
                        cmeas = [{
                            "program": cmet.s1,
                            "funder": cmet.s2,
                            "countries": cmet.s3,
                            "healthfocus": cmet.s4,
                            "improvement": cmet.s5
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                        tmeas.append({
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "ProgramImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "ProgramImpact2"]
                newMet = {
                    "label": "ProgramImpact2",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "program": cmet.s1,
                                                        "funder": cmet.s2,
                                                        "countries": cmet.s3,
                                                        "healthfocus": cmet.s4,
                                                        "improvement": cmet.s5
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "CountryImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s7

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s8

            mets = [z for z in db_result["custommeasure"] if z["label"] != "CountryImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "CountryImpact"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "CountryImpact"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    else:
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "countries": cmet.s1,
                        "facilities": cmet.s2,
                        "patients": cmet.s3
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s7,
                        "value": quarterData
                    })
                    newMet = {
                        "label": "CountryImpact",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in remoteData["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                            cmeas.append({
                                "countries": cmet.s1,
                                "facilities": cmet.s2,
                                "patients": cmet.s3
                            })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                        quarterData2 = []
                        quarterData2.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData2
                        })
                        newMet = {
                            "label": "CountryImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)   
                    else:
                        cmeas = [{
                            "countries": cmet.s1,
                            "facilities": cmet.s2,
                            "patients": cmet.s3
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                        tmeas.append({
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "CountryImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "CountryImpact"]
                newMet = {
                    "label": "CountryImpact",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "countries": cmet.s1,
                                                        "facilities": cmet.s2,
                                                        "patients": cmet.s3
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "MacroImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "MacroImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "MacroImpact"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "MacroImpact"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "name": cmet.s1,
                        "funder": cmet.s2,
                        "healthfocus": cmet.s3,
                        "countries": cmet.s4,
                        "healthfacilities": cmet.s5,
                        "patients": cmet.s6
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "MacroImpact",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    cmeas = [{
                        "name": cmet.s1,
                        "funder": cmet.s2,
                        "healthfocus": cmet.s3,
                        "countries": cmet.s4,
                        "healthfacilities": cmet.s5,
                        "patients": cmet.s6
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "MacroImpact",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            
            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "MacroImpact"]
                newMet = {
                    "label": "MacroImpact",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "name": cmet.s1,
                                                        "funder": cmet.s2,
                                                        "healthfocus": cmet.s3,
                                                        "countries": cmet.s4,
                                                        "healthfacilities": cmet.s5,
                                                        "patients": cmet.s6
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "OncolensImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "OncolensImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "OncolensImpact"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "OncolensImpact"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "device": cmet.s1,
                        "licenses": cmet.s3,
                        "countries": cmet.s11
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s7,
                        "value": quarterData
                    })
                    newMet = {
                        "label": "OncolensImpact",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    cmeas = [{
                        "device": cmet.s1,
                        "licenses": cmet.s3,
                        "countries": cmet.s11
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                        "label": cmet.s7,
                        "value": [
                            {
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas
                                    }
                                ]
                            }
                        ]
                    })
                    newMet = {
                        "label": "OncolensImpact",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "OncolensImpact"]
                newMet = {
                    "label": "OncolensImpact",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "device": cmet.s1,
                                                        "licenses": cmet.s3,
                                                        "countries": cmet.s11
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row1":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row1"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row1"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "Row1"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "conferences": cmet.s1,
                        "countries": cmet.s11
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "Row1",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    cmeas = [{
                        "conferences": cmet.s1,
                        "countries": cmet.s11
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                        "label": cmet.s7,
                        "value": [
                            {
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas
                                    }
                                ]
                            }
                        ]
                    })
                    newMet = {
                        "label": "Row1",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "Row1"]
                newMet = {
                    "label": "Row1",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "conferences": cmet.s1,
                                                        "countries": cmet.s11
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row2":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row2"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row2"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "Row2"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "conferences": cmet.s1,
                        "countries": cmet.s11
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "Row2",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    cmeas = [{
                        "conferences": cmet.s1,
                        "countries": cmet.s11
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                        "label": cmet.s7,
                        "value": [
                            {
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas
                                    }
                                ]
                            }
                        ]
                    })
                    newMet = {
                        "label": "Row2",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "Row2"]
                newMet = {
                    "label": "Row2",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "conferences": cmet.s1,
                                                        "countries": cmet.s11
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row3":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row3"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row3"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "Row3"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "conferences": cmet.s1,
                        "patients": cmet.s2,
                        "countries": cmet.s11
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "Row3",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    cmeas = [{
                        "conferences": cmet.s1,
                        "patients": cmet.s2,
                        "countries": cmet.s11
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                        "label": cmet.s7,
                        "value": [
                            {
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas
                                    }
                                ]
                            }
                        ]
                    })
                    newMet = {
                        "label": "Row3",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "Row3"]
                newMet = {
                    "label": "Row3",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "conferences": cmet.s1,
                                                        "patients": cmet.s2,
                                                        "countries": cmet.s11
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row4":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row4"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row4"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "Row4"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "conferences": cmet.s1,
                        "countries": cmet.s11
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "Row4",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    cmeas = [{
                        "conferences": cmet.s1,
                        "countries": cmet.s11
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                        "label": cmet.s7,
                        "value": [
                            {
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas
                                    }
                                ]
                            }
                        ]
                    })
                    newMet = {
                        "label": "Row4",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "Row4"]
                newMet = {
                    "label": "Row4",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "conferences": cmet.s1,
                                                        "countries": cmet.s11
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row5":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row5"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row5"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "Row5"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "conferences": cmet.s1,
                        "countries": cmet.s11
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "Row5",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    cmeas = [{
                        "conferences": cmet.s1,
                        "countries": cmet.s11
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                        "label": cmet.s7,
                        "value": [
                            {
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas
                                    }
                                ]
                            }
                        ]
                    })
                    newMet = {
                        "label": "Row5",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "Row5"]
                newMet = {
                    "label": "Row5",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "conferences": cmet.s1,
                                                        "countries": cmet.s11
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "SonioImpact2":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact2"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "SonioImpact2"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "SonioImpact2"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "distributor": cmet.s1,
                        "expert": cmet.s3,
                        "countries": cmet.s11
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "SonioImpact2",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    cmeas = [{
                        "distributor": cmet.s1,
                        "expert": cmet.s3,
                        "countries": cmet.s11
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "SonioImpact2",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact2"]
                newMet = {
                    "label": "SonioImpact2",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "distributor": cmet.s1,
                                                        "expert": cmet.s3,
                                                        "countries": cmet.s11
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "SonioImpact3":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact3"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "SonioImpact3"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "SonioImpact3"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "device": cmet.s1,
                        "licenses": cmet.s3,
                        "countries": cmet.s11
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "SonioImpact3",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    cmeas = [{
                        "device": cmet.s1,
                        "licenses": cmet.s3,
                        "countries": cmet.s11
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                        "label": cmet.s7,
                        "value": [
                            {
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas
                                    }
                                ]
                            }
                        ]
                    })
                    newMet = {
                        "label": "SonioImpact3",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact3"]
                newMet = {
                    "label": "SonioImpact3",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "device": cmet.s1,
                                                        "licenses": cmet.s3,
                                                        "countries": cmet.s11
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "SonioImpact4":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact4"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "SonioImpact4"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "SonioImpact4"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "distributor": cmet.s1,
                        "expert": cmet.s3,
                        "countries": cmet.s11
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "SonioImpact4",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    cmeas = [{
                        "distributor": cmet.s1,
                        "expert": cmet.s3,
                        "countries": cmet.s11
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                                "label": cmet.s7,
                                "value": [
                                    {
                                        "label": cmet.s8,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas
                                            }
                                        ]
                                    }
                                ]
                            })
                    newMet = {
                        "label": "SonioImpact4",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact4"]
                newMet = {
                    "label": "SonioImpact4",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "distributor": cmet.s1,
                                                        "expert": cmet.s3,
                                                        "countries": cmet.s11
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "momRow3":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "momRow3"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "momRow3"]):
                remoteData = [z for z in db_result["custommeasure"] if z["label"] == "momRow3"][0]
                if ([a for a in remoteData["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    cmeas = []
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        cmeas = myData["metrics"][0]["value"]
                    cmeas.append({
                        "devices": cmet.s1,
                        "countries": cmet.s11
                    })
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    quarterData.append({
                        "label": cmet.s8,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeas
                            }
                        ]
                    })
                    tmeas.append({
                                "label": cmet.s7,
                                "value": quarterData
                            })
                    newMet = {
                        "label": "momRow3",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                else:
                    cmeas = [{
                        "devices": cmet.s1,
                        "countries": cmet.s11
                    }]
                    tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s7]
                    tmeas.append({
                        "label": cmet.s7,
                        "value": [
                            {
                                "label": cmet.s8,
                                "metrics": [
                                    {
                                        "label": "1",
                                        "value": cmeas
                                    }
                                ]
                            }
                        ]
                    })
                    newMet = {
                        "label": "momRow3",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

            else:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                mets = [z for z in db_result["custommeasure"] if z["label"] != "momRow3"]
                newMet = {
                    "label": "momRow3",
                    "metrics": [
                        {
                            "label": cmet.s7,
                            "value": [
                                {
                                    "label": cmet.s8,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value":
                                                [
                                                    {
                                                        "devices": cmet.s1,
                                                        "countries": cmet.s11
                                                    }
                                                ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
                mets.append(newMet)
                target = {
                    "custommeasure": mets
                }
                user.update(target)
                callConnect.container15.upsert_item(body=user)
        
"""
Endppoint use to edit rows on the GobiPage
"""
@customsroute.post('/custommeasureGobiRowsEdit')
async def gobi_measure_edit(cmet: CarbonMeasureEdit2):
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasureedit')
        return {"url": "/", "atype": False}

    if "custommeasure" in db_result:
        if cmet.metric == "CorporateImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s10

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s11

            mets = [z for z in db_result["custommeasure"] if z["label"] != "CorporateImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "CorporateImpact"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "CorporateImpact"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["contract"] != cmet.s6 or z["funder"] != cmet.s7 or z["customer"] != cmet.s8 or z["countries"] != cmet.s16 or z["sales"] != cmet.s12]
                        cmeasNEW.append({
                            "contract": cmet.s1,
                            "funder": cmet.s2,
                            "customer": cmet.s3,
                            "countries": cmet.s15,
                            "sales": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "CorporateImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]

                        cmeasNEW = [z for z in cmeas if z["contract"] != cmet.s6 or z["funder"] != cmet.s7 or z["customer"] != cmet.s8 or z["countries"] != cmet.s16 or z["sales"] != cmet.s12]
                        cmeasNEW.append({
                            "contract": cmet.s1,
                            "funder": cmet.s2,
                            "customer": cmet.s3,
                            "countries": cmet.s15,
                            "sales": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "CorporateImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in nmet["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]

                        myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["contract"] != cmet.s6 or z["funder"] != cmet.s7 or z["customer"] != cmet.s8 or z["countries"] != cmet.s16 or z["sales"] != cmet.s12]
                        cmeasNEW.append({
                            "contract": cmet.s1,
                            "funder": cmet.s2,
                            "customer": cmet.s3,
                            "countries": cmet.s15,
                            "sales": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData2 = []
                        quarterData2.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData2
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "CorporateImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                        quarterData = []
                        cmeasNEW = []
                        cmeasNEW.append({
                            "contract": cmet.s1,
                            "funder": cmet.s2,
                            "customer": cmet.s3,
                            "countries": cmet.s15,
                            "sales": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "CorporateImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "PatientVolume":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s10

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s11

            mets = [z for z in db_result["custommeasure"] if z["label"] != "PatientVolume"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "PatientVolume"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "PatientVolume"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["highbirth"] != cmet.s4 or z["mediumbirth"] != cmet.s5 or z["lowbirth"] != cmet.s6]
                        cmeasNEW.append({
                            "highbirth": cmet.s1,
                            "mediumbirth": cmet.s2,
                            "lowbirth": cmet.s3
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "PatientVolume",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]

                        cmeasNEW = [z for z in cmeas if z["highbirth"] != cmet.s4 or z["mediumbirth"] != cmet.s5 or z["lowbirth"] != cmet.s6]
                        cmeasNEW.append({
                            "highbirth": cmet.s1,
                            "mediumbirth": cmet.s2,
                            "lowbirth": cmet.s3
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "PatientVolume",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in nmet["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]

                        myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["highbirth"] != cmet.s4 or z["mediumbirth"] != cmet.s5 or z["lowbirth"] != cmet.s6]
                        cmeasNEW.append({
                            "highbirth": cmet.s1,
                            "mediumbirth": cmet.s2,
                            "lowbirth": cmet.s3
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData2 = []
                        quarterData2.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData2
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "PatientVolume",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                        quarterData = []
                        cmeasNEW = []
                        cmeasNEW.append({
                            "highbirth": cmet.s1,
                            "mediumbirth": cmet.s2,
                            "lowbirth": cmet.s3
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "PatientVolume",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "ProgramImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s10

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s11

            mets = [z for z in db_result["custommeasure"] if z["label"] != "ProgramImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "ProgramImpact"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "ProgramImpact"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["program"] != cmet.s6 or z["funder"] != cmet.s7 or z["countries"] != cmet.s8 or z["healthfocus"] != cmet.s9 or z["improvement"] != cmet.s12]
                        cmeasNEW.append({
                            "program": cmet.s1,
                            "funder": cmet.s2,
                            "countries": cmet.s3,
                            "healthfocus": cmet.s4,
                            "improvement": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "ProgramImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]

                        cmeasNEW = [z for z in cmeas if z["program"] != cmet.s6 or z["funder"] != cmet.s7 or z["countries"] != cmet.s8 or z["healthfocus"] != cmet.s9 or z["improvement"] != cmet.s12]
                        cmeasNEW.append({
                            "program": cmet.s1,
                            "funder": cmet.s2,
                            "countries": cmet.s3,
                            "healthfocus": cmet.s4,
                            "improvement": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "ProgramImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in nmet["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]

                        myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["program"] != cmet.s6 or z["funder"] != cmet.s7 or z["countries"] != cmet.s8 or z["healthfocus"] != cmet.s9 or z["improvement"] != cmet.s12]
                        cmeasNEW.append({
                            "program": cmet.s1,
                            "funder": cmet.s2,
                            "countries": cmet.s3,
                            "healthfocus": cmet.s4,
                            "improvement": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData2 = []
                        quarterData2.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData2
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "ProgramImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                        quarterData = []
                        cmeasNEW = []
                        cmeasNEW.append({
                            "program": cmet.s1,
                            "funder": cmet.s2,
                            "countries": cmet.s3,
                            "healthfocus": cmet.s4,
                            "improvement": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "ProgramImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "ProgramImpact2":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s10

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s11

            mets = [z for z in db_result["custommeasure"] if z["label"] != "ProgramImpact2"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "ProgramImpact2"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "ProgramImpact2"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["program"] != cmet.s6 or z["funder"] != cmet.s7 or z["countries"] != cmet.s8 or z["healthfocus"] != cmet.s9 or z["improvement"] != cmet.s12]
                        cmeasNEW.append({
                            "program": cmet.s1,
                            "funder": cmet.s2,
                            "countries": cmet.s3,
                            "healthfocus": cmet.s4,
                            "improvement": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "ProgramImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]

                        cmeasNEW = [z for z in cmeas if z["program"] != cmet.s6 or z["funder"] != cmet.s7 or z["countries"] != cmet.s8 or z["healthfocus"] != cmet.s9 or z["improvement"] != cmet.s12]
                        cmeasNEW.append({
                            "program": cmet.s1,
                            "funder": cmet.s2,
                            "countries": cmet.s3,
                            "healthfocus": cmet.s4,
                            "improvement": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "ProgramImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in nmet["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]

                        myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["program"] != cmet.s6 or z["funder"] != cmet.s7 or z["countries"] != cmet.s8 or z["healthfocus"] != cmet.s9 or z["improvement"] != cmet.s12]
                        cmeasNEW.append({
                            "program": cmet.s1,
                            "funder": cmet.s2,
                            "countries": cmet.s3,
                            "healthfocus": cmet.s4,
                            "improvement": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData2 = []
                        quarterData2.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData2
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "ProgramImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                        quarterData = []
                        cmeasNEW = []
                        cmeasNEW.append({
                            "program": cmet.s1,
                            "funder": cmet.s2,
                            "countries": cmet.s3,
                            "healthfocus": cmet.s4,
                            "improvement": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "ProgramImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "CountryImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s10

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s11
            mets = [z for z in db_result["custommeasure"] if z["label"] != "CountryImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "CountryImpact"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "CountryImpact"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["countries"] != cmet.s4 or z["facilities"] != cmet.s5 or z["patients"] != cmet.s6]
                        cmeasNEW.append({
                            "countries": cmet.s1,
                            "facilities": cmet.s2,
                            "patients": cmet.s3
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "CountryImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]

                        cmeasNEW = [z for z in cmeas if z["countries"] != cmet.s4 or z["facilities"] != cmet.s5 or z["patients"] != cmet.s6]
                        cmeasNEW.append({
                            "countries": cmet.s1,
                            "facilities": cmet.s2,
                            "patients": cmet.s3
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "CountryImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in nmet["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]

                        myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]                        
                        cmeasNEW = [z for z in cmeas if z["countries"] != cmet.s4 or z["facilities"] != cmet.s5 or z["patients"] != cmet.s6]
                        cmeasNEW.append({
                            "countries": cmet.s1,
                            "facilities": cmet.s2,
                            "patients": cmet.s3
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData2 = []
                        quarterData2.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData2
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "ProgramImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                        quarterData = []
                        cmeasNEW = []
                        cmeasNEW.append({
                            "countries": cmet.s1,
                            "facilities": cmet.s2,
                            "patients": cmet.s3
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "CountryImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "MacroImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "MacroImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "MacroImpact"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "MacroImpact"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["name"] != cmet.s7 or z["funder"] != cmet.s8 or z["healthfocus"] != cmet.s9 or z["countries"] != cmet.s12 or z["healthfacilities"] != cmet.s13 or z["patients"] != cmet.s14]
                        cmeasNEW.append({
                            "name": cmet.s1,
                            "funder": cmet.s2,
                            "healthfocus": cmet.s3,
                            "countries": cmet.s4,
                            "healthfacilities": cmet.s5,
                            "patients": cmet.s6
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "MacroImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "OncolensImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "OncolensImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "OncolensImpact"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "OncolensImpact"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["conferences"] != cmet.s6 or z["patients"] != cmet.s7 or z["women"] != cmet.s8 or z["countries"] != cmet.s16 or z["pediatric"] != cmet.s12]
                        cmeasNEW.append({
                            "conferences": cmet.s1,
                            "patients": cmet.s2,
                            "women": cmet.s3,
                            "countries": cmet.s15,
                            "pediatric": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "OncolensImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "conferences": cmet.s1,
                            "patients": cmet.s2,
                            "women": cmet.s3,
                            "countries": cmet.s15,
                            "pediatric": cmet.s5
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "OncolensImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "conferences": cmet.s1,
                        "patients": cmet.s2,
                        "women": cmet.s3,
                        "countries": cmet.s15,
                        "pediatric": cmet.s5
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    newMet = {
                        "label": "OncolensImpact",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row1":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row1"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row1"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "Row1"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["conferences"] != cmet.s6 or z["countries"] != cmet.s16]
                        cmeasNEW.append({
                            "conferences": cmet.s1,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row1",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "conferences": cmet.s1,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row1",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "conferences": cmet.s1,
                        "countries": cmet.s15
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    newMet = {
                        "label": "Row1",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row2":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row2"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row2"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "Row2"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["conferences"] != cmet.s6 or z["countries"] != cmet.s16]
                        cmeasNEW.append({
                            "conferences": cmet.s1,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "conferences": cmet.s1,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "conferences": cmet.s1,
                        "countries": cmet.s15
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    newMet = {
                        "label": "Row2",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row3":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row3"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row3"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "Row3"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["conferences"] != cmet.s6 or z["patients"] != cmet.s7 or z["countries"] != cmet.s16]
                        cmeasNEW.append({
                            "conferences": cmet.s1,
                            "patients": cmet.s2,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row3",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "conferences": cmet.s1,
                            "patients": cmet.s2,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row3",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "conferences": cmet.s1,
                        "patients": cmet.s2,
                        "countries": cmet.s15
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    newMet = {
                        "label": "Row3",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row4":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row4"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row4"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "Row4"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["conferences"] != cmet.s6 or z["countries"] != cmet.s16]
                        cmeasNEW.append({
                            "conferences": cmet.s1,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row4",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "conferences": cmet.s1,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row4",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "conferences": cmet.s1,
                        "countries": cmet.s15
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    newMet = {
                        "label": "Row4",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row5":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row5"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row5"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "Row5"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["conferences"] != cmet.s6 or z["countries"] != cmet.s16]
                        cmeasNEW.append({
                            "conferences": cmet.s1,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row5",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "conferences": cmet.s1,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row5",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "conferences": cmet.s1,
                        "countries": cmet.s15
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    newMet = {
                        "label": "Row5",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "SonioImpact2":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact2"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "SonioImpact2"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "SonioImpact2"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["distributor"] != cmet.s6 or z["expert"] != cmet.s7 or z["countries"] != cmet.s16]
                        cmeasNEW.append({
                            "distributor": cmet.s1,
                            "expert": cmet.s2,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "SonioImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "distributor": cmet.s1,
                            "expert": cmet.s2,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "SonioImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "distributor": cmet.s1,
                        "expert": cmet.s2,
                        "countries": cmet.s15
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    newMet = {
                        "label": "SonioImpact2",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "SonioImpact3":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact3"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "SonioImpact3"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "SonioImpact3"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["device"] != cmet.s6 or z["licenses"] != cmet.s7 or z["countries"] != cmet.s16]
                        cmeasNEW.append({
                            "device": cmet.s1,
                            "licenses": cmet.s2,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "SonioImpact3",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "device": cmet.s1,
                            "licenses": cmet.s2,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "SonioImpact3",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "device": cmet.s1,
                        "licenses": cmet.s2,
                        "countries": cmet.s15
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    newMet = {
                        "label": "SonioImpact3",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "SonioImpact4":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact4"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "SonioImpact4"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "SonioImpact4"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["distributor"] != cmet.s6 or z["expert"] != cmet.s7 or z["countries"] != cmet.s16]
                        cmeasNEW.append({
                            "distributor": cmet.s1,
                            "expert": cmet.s2,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "SonioImpact4",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "distributor": cmet.s1,
                            "expert": cmet.s2,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "SonioImpact4",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "distributor": cmet.s1,
                        "expert": cmet.s2,
                        "countries": cmet.s15
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    newMet = {
                        "label": "SonioImpact4",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "momRow3":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "momRow3"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "momRow3"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "momRow3"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s10]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s10][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s11]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["devices"] != cmet.s6 or z["countries"] != cmet.s16]
                        cmeasNEW.append({
                            "devices": cmet.s1,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s10,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "momRow3",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        myData = [bb for bb in yearData["value"] if bb["label"] != cmet.s11][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = []
                        cmeasNEW.append({
                            "devices": cmet.s1,
                            "countries": cmet.s15
                        })
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                        quarterData.append({
                            "label": cmet.s11,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s10,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "momRow3",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] != cmet.s10][0]
                    quarterData = []
                    cmeasNEW = []
                    cmeasNEW.append({
                        "devices": cmet.s1,
                        "countries": cmet.s15
                    })
                    tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s10]
                    quarterData.append({
                        "label": cmet.s11,
                        "metrics": [
                            {
                                "label": "1",
                                "value": cmeasNEW
                            }
                        ]
                    })
                    tmeas.append({
                        "label": cmet.s10,
                        "value": quarterData
                    })
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    newMet = {
                        "label": "momRow3",
                        "metrics": tmeas
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
        
"""
Endppoint use to add delete to the GobiPage
"""
@customsroute.post('/custommeasureGobiRowsDelete')
async def gobi_measure_delete(cmet: CarbonMeasure):
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /carbonmeasuredelete')
        return {"url": "/", "atype": False}


    if "custommeasure" in db_result:
        if cmet.metric == "CorporateImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s7

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s8

            mets = [z for z in db_result["custommeasure"] if z["label"] != "CorporateImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "CorporateImpact"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "CorporateImpact"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]

                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["contract"] != cmet.s1 or z["funder"] != cmet.s2 or z["customer"] != cmet.s3 or z["countries"] != cmet.s11 or z["sales"] != cmet.s5]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]

                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "CorporateImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                                                
                        cmeasNEW = [z for z in cmeas if z["contract"] != cmet.s1 or z["funder"] != cmet.s2 or z["customer"] != cmet.s3 or z["countries"] != cmet.s11 or z["sales"] != cmet.s5]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "CorporateImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in nmet["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]                        
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]

                        cmeasNEW = [z for z in cmeas if z["contract"] != cmet.s1 or z["funder"] != cmet.s2 or z["customer"] != cmet.s3 or z["countries"] != cmet.s11 or z["sales"] != cmet.s5]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "CorporateImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "PatientVolume":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s7

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s8

            mets = [z for z in db_result["custommeasure"] if z["label"] != "PatientVolume"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "PatientVolume"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "PatientVolume"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["highbirth"] != cmet.s1 or z["mediumbirth"] != cmet.s2 or z["lowbirth"] != cmet.s3]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "PatientVolume",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                        
                        cmeasNEW = [z for z in cmeas if z["highbirth"] != cmet.s1 or z["mediumbirth"] != cmet.s2 or z["lowbirth"] != cmet.s3]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "PatientVolume",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in nmet["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]                        
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                            
                        cmeasNEW = [z for z in cmeas if z["highbirth"] != cmet.s1 or z["mediumbirth"] != cmet.s2 or z["lowbirth"] != cmet.s3]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "PatientVolume",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "ProgramImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s7

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s8
            
            mets = [z for z in db_result["custommeasure"] if z["label"] != "ProgramImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "ProgramImpact"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "ProgramImpact"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["program"] != cmet.s1 or z["funder"] != cmet.s2 or z["countries"] != cmet.s3 or z["healthfocus"] != cmet.s4 or z["improvement"] != cmet.s5]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "ProgramImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                        
                        cmeasNEW = [z for z in cmeas if z["program"] != cmet.s1 or z["funder"] != cmet.s2 or z["countries"] != cmet.s3 or z["healthfocus"] != cmet.s4 or z["improvement"] != cmet.s5]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "ProgramImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in nmet["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]                        
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                            
                        cmeasNEW = [z for z in cmeas if z["program"] != cmet.s1 or z["funder"] != cmet.s2 or z["countries"] != cmet.s3 or z["healthfocus"] != cmet.s4 or z["improvement"] != cmet.s5]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "ProgramImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "ProgramImpact2":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s7

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s8
            
            mets = [z for z in db_result["custommeasure"] if z["label"] != "ProgramImpact2"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "ProgramImpact2"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "ProgramImpact2"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["program"] != cmet.s1 or z["funder"] != cmet.s2 or z["countries"] != cmet.s3 or z["healthfocus"] != cmet.s4 or z["improvement"] != cmet.s5]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "ProgramImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                        
                        cmeasNEW = [z for z in cmeas if z["program"] != cmet.s1 or z["funder"] != cmet.s2 or z["countries"] != cmet.s3 or z["healthfocus"] != cmet.s4 or z["improvement"] != cmet.s5]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "ProgramImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    if ([a for a in nmet["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]                        
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                            
                        cmeasNEW = [z for z in cmeas if z["program"] != cmet.s1 or z["funder"] != cmet.s2 or z["countries"] != cmet.s3 or z["healthfocus"] != cmet.s4 or z["improvement"] != cmet.s5]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "ProgramImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "CountryImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            Qyear = ""
            Qquar = ""
            if len(cmet.persistYear) > 0:
                Qyear = cmet.persistYear
            else:
                Qyear = cmet.s7

            if len(cmet.persistQuar) > 0:
                Qquar = cmet.persistQuar
            else:
                Qquar = cmet.s8
            
            mets = [z for z in db_result["custommeasure"] if z["label"] != "CountryImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "CountryImpact"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "CountryImpact"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["countries"] != cmet.s1 or z["facilities"] != cmet.s2 or z["patients"] != cmet.s3]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "CountryImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                        
                        cmeasNEW = [z for z in cmeas if z["countries"] != cmet.s1 or z["facilities"] != cmet.s2 or z["patients"] != cmet.s3]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "CountryImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)                        
                else:
                    if ([a for a in nmet["metrics"] if a["label"] == Qyear]):
                        yearData = [aa for aa in nmet["metrics"] if aa["label"] == Qyear][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != Qquar]                        
                        cmeas = []
                        if ([bb for bb in yearData["value"] if bb["label"] == Qquar]):
                            myData = [bb for bb in yearData["value"] if bb["label"] == Qquar][0]
                            cmeas = myData["metrics"][0]["value"]
                            
                        cmeasNEW = [z for z in cmeas if z["countries"] != cmet.s1 or z["facilities"] != cmet.s2 or z["patients"] != cmet.s3]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "CountryImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "MacroImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "MacroImpact"]

            if ([z for z in db_result["custommeasure"] if z["label"] == "MacroImpact"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "MacroImpact"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["name"] != cmet.s1 or z["funder"] != cmet.s2 or z["healthfocus"] != cmet.s3 or z["countries"] != cmet.s4 or z["healthfacilities"] != cmet.s5 or z["patients"] != cmet.s6]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "MacroImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "OncolensImpact":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "OncolensImpact"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "OncolensImpact"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "OncolensImpact"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["conferences"] != cmet.s1 or z["patients"] != cmet.s2 or z["women"] != cmet.s3 or z["countries"] != cmet.s11 or z["pediatric"] != cmet.s5]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]                        
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "OncolensImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row1":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row1"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row1"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "Row1"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["conferences"] != cmet.s1 or z["countries"] != cmet.s11]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]                        
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row1",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row2":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row2"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row2"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "Row2"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["conferences"] != cmet.s1 or z["countries"] != cmet.s11]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]                        
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row3":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row3"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row3"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "Row3"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["conferences"] != cmet.s1 or z["patients"] != cmet.s2 or z["countries"] != cmet.s11]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]                        
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row3",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row4":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row4"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row4"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "Row4"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["conferences"] != cmet.s1 or z["countries"] != cmet.s11]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]                        
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row4",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "Row5":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "Row5"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "Row5"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "Row5"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["conferences"] != cmet.s1 or z["countries"] != cmet.s11]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]                        
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "Row5",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "SonioImpact2":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact2"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "SonioImpact2"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "SonioImpact2"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["distributor"] != cmet.s1 or z["expert"] != cmet.s2 or z["countries"] != cmet.s11]                        
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]                        
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "SonioImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "SonioImpact3":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact3"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "SonioImpact3"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "SonioImpact3"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["device"] != cmet.s1 or z["licenses"] != cmet.s2 or z["countries"] != cmet.s11]                        
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "SonioImpact3",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "SonioImpact4":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact4"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "SonioImpact4"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "SonioImpact4"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["distributor"] != cmet.s1 or z["expert"] != cmet.s2 or z["countries"] != cmet.s11]                        
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]                        
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                                    "label": cmet.s7,
                                    "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "SonioImpact4",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        elif cmet.metric == "momRow3":
            user = {
                "id": db_result["id"],
                "email": db_result["email"],
                "custommeasure": []
            }
            mets = [z for z in db_result["custommeasure"] if z["label"] != "momRow3"]
            if ([z for z in db_result["custommeasure"] if z["label"] == "momRow3"]):
                nmet = [z for z in db_result["custommeasure"] if z["label"] == "momRow3"][0]
                if ([a for a in nmet["metrics"] if a["label"] == cmet.s7]):
                    yearData = [aa for aa in nmet["metrics"] if aa["label"] == cmet.s7][0]
                    quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s8]
                    if ([bb for bb in yearData["value"] if bb["label"] == cmet.s8]):
                        myData = [bb for bb in yearData["value"] if bb["label"] == cmet.s8][0]
                        nmetlis = [z for z in myData["metrics"] if z["label"] == "1"]
                        cmeas = nmetlis[0]["value"]
                        cmeasNEW = [z for z in cmeas if z["devices"] != cmet.s1 or z["countries"] != cmet.s11]
                        tmeas = [a for a in nmet["metrics"] if a["label"] != cmet.s7]                        
                        quarterData.append({
                            "label": cmet.s8,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeasNEW
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s7,
                            "value": quarterData
                        })
                        user = {
                            "id": db_result["id"],
                            "email": db_result["email"],
                            "custommeasure": []
                        }
                        newMet = {
                            "label": "momRow3",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
        
"""
Endpoint used to update the custom metrics for Activate measurement
"""
@customsroute.post('/custommeasureActivate')
async def custom_measure_activate(cmet: ActivateMeasure):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "EnvironmentalImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "EnvironmentalImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "EnvironmentalImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "EnvironmentalImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "var13": cmet.s32,
                            "var14": cmet.s33,
                            "var15": cmet.s34,
                            "var16": cmet.s35,
                            "var17": cmet.s36,
                            "var18": cmet.s37,
                            "var19": cmet.s38,
                            "var20": cmet.s39,
                            "var21": cmet.s40,
                            "var22": cmet.s41,
                            "var23": cmet.s42
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "var13": cmet.s32,
                            "var14": cmet.s33,
                            "var15": cmet.s34,
                            "var16": cmet.s35,
                            "var17": cmet.s36,
                            "var18": cmet.s37,
                            "var19": cmet.s38,
                            "var20": cmet.s39,
                            "var21": cmet.s40,
                            "var22": cmet.s41,
                            "var23": cmet.s42
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "EnvironmentalImpact"]
                    newMet = {
                        "label": "EnvironmentalImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31,
                                                            "var13": cmet.s32,
                                                            "var14": cmet.s33,
                                                            "var15": cmet.s34,
                                                            "var16": cmet.s35,
                                                            "var17": cmet.s36,
                                                            "var18": cmet.s37,
                                                            "var19": cmet.s38,
                                                            "var20": cmet.s39,
                                                            "var21": cmet.s40,
                                                            "var22": cmet.s41,
                                                            "var23": cmet.s42
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "OverviewMeasure":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "OverviewMeasure"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "OverviewMeasure"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "OverviewMeasure"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "OverviewMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "OverviewMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "OverviewMeasure"]
                    newMet = {
                        "label": "OverviewMeasure",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "GovernanceImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "GovernanceImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "GovernanceImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "WMToday": cmet.s1,
                            "WMYear": cmet.s2,
                            "WMNoplans": cmet.s3,
                            "ClimateToday": cmet.s4,
                            "ClimateYear": cmet.s7,
                            "ClimateNoplans": cmet.s8,
                            "EnvironmentToday": cmet.s9,
                            "EnvironmentYear": cmet.s10,
                            "EnvironmentNoplans": cmet.s11,
                            "PaidToday": cmet.s12,
                            "PaidYear": cmet.s13,
                            "PaidNoplans": cmet.s14,
                            "ResponsibleToday": cmet.s15,
                            "ResponsibleYear": cmet.s16,
                            "ResponsibleNoplans": cmet.s17,
                            "WorkforceToday": cmet.s18,
                            "WorkforceYear": cmet.s19,
                            "WorkforceNoplans": cmet.s20,
                            "DiversityToday": cmet.s21,
                            "DiversityYear": cmet.s22,
                            "DiversityNoplans": cmet.s23,
                            "ProcessToday": cmet.s24,
                            "ProcessYear": cmet.s25,
                            "ProcessNoplans": cmet.s26,
                            "FairToday": cmet.s27,
                            "FairYear": cmet.s28,
                            "FairNoplans": cmet.s29,
                            "PaidToday": cmet.s30,
                            "PaidYear": cmet.s31,
                            "PaidNoplans": cmet.s32,
                            "ResponsibleToday": cmet.s33,
                            "ResponsibleYear": cmet.s34,
                            "ResponsibleNoplans": cmet.s35,
                            "SecurityToday": cmet.s36,
                            "SecurityYear": cmet.s37,
                            "SecurityNoplans": cmet.s38,
                            "CodeToday": cmet.s39,
                            "CodeYear": cmet.s40,
                            "CodeNoplans": cmet.s41,
                            "OtherToday": cmet.s42,
                            "OtherYear": cmet.s43,
                            "OtherNoplans": cmet.s44,
                            "Commentary": cmet.s45,
                            "Help": cmet.s46,
                            "BeyondPolicy": cmet.s47
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "WMToday": cmet.s1,
                            "WMYear": cmet.s2,
                            "WMNoplans": cmet.s3,
                            "ClimateToday": cmet.s4,
                            "ClimateYear": cmet.s7,
                            "ClimateNoplans": cmet.s8,
                            "EnvironmentToday": cmet.s9,
                            "EnvironmentYear": cmet.s10,
                            "EnvironmentNoplans": cmet.s11,
                            "PaidToday": cmet.s12,
                            "PaidYear": cmet.s13,
                            "PaidNoplans": cmet.s14,
                            "ResponsibleToday": cmet.s15,
                            "ResponsibleYear": cmet.s16,
                            "ResponsibleNoplans": cmet.s17,
                            "WorkforceToday": cmet.s18,
                            "WorkforceYear": cmet.s19,
                            "WorkforceNoplans": cmet.s20,
                            "DiversityToday": cmet.s21,
                            "DiversityYear": cmet.s22,
                            "DiversityNoplans": cmet.s23,
                            "ProcessToday": cmet.s24,
                            "ProcessYear": cmet.s25,
                            "ProcessNoplans": cmet.s26,
                            "FairToday": cmet.s27,
                            "FairYear": cmet.s28,
                            "FairNoplans": cmet.s29,
                            "PaidToday": cmet.s30,
                            "PaidYear": cmet.s31,
                            "PaidNoplans": cmet.s32,
                            "ResponsibleToday": cmet.s33,
                            "ResponsibleYear": cmet.s34,
                            "ResponsibleNoplans": cmet.s35,
                            "SecurityToday": cmet.s36,
                            "SecurityYear": cmet.s37,
                            "SecurityNoplans": cmet.s38,
                            "CodeToday": cmet.s39,
                            "CodeYear": cmet.s40,
                            "CodeNoplans": cmet.s41,
                            "OtherToday": cmet.s42,
                            "OtherYear": cmet.s43,
                            "OtherNoplans": cmet.s44,
                            "Commentary": cmet.s45,
                            "Help": cmet.s46,
                            "BeyondPolicy": cmet.s47
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "GovernanceImpact"]
                    newMet = {
                        "label": "GovernanceImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "WMToday": cmet.s1,
                                                            "WMYear": cmet.s2,
                                                            "WMNoplans": cmet.s3,
                                                            "ClimateToday": cmet.s4,
                                                            "ClimateYear": cmet.s7,
                                                            "ClimateNoplans": cmet.s8,
                                                            "EnvironmentToday": cmet.s9,
                                                            "EnvironmentYear": cmet.s10,
                                                            "EnvironmentNoplans": cmet.s11,
                                                            "PaidToday": cmet.s12,
                                                            "PaidYear": cmet.s13,
                                                            "PaidNoplans": cmet.s14,
                                                            "ResponsibleToday": cmet.s15,
                                                            "ResponsibleYear": cmet.s16,
                                                            "ResponsibleNoplans": cmet.s17,
                                                            "WorkforceToday": cmet.s18,
                                                            "WorkforceYear": cmet.s19,
                                                            "WorkforceNoplans": cmet.s20,
                                                            "DiversityToday": cmet.s21,
                                                            "DiversityYear": cmet.s22,
                                                            "DiversityNoplans": cmet.s23,
                                                            "ProcessToday": cmet.s24,
                                                            "ProcessYear": cmet.s25,
                                                            "ProcessNoplans": cmet.s26,
                                                            "FairToday": cmet.s27,
                                                            "FairYear": cmet.s28,
                                                            "FairNoplans": cmet.s29,
                                                            "PaidToday": cmet.s30,
                                                            "PaidYear": cmet.s31,
                                                            "PaidNoplans": cmet.s32,
                                                            "ResponsibleToday": cmet.s33,
                                                            "ResponsibleYear": cmet.s34,
                                                            "ResponsibleNoplans": cmet.s35,
                                                            "SecurityToday": cmet.s36,
                                                            "SecurityYear": cmet.s37,
                                                            "SecurityNoplans": cmet.s38,
                                                            "CodeToday": cmet.s39,
                                                            "CodeYear": cmet.s40,
                                                            "CodeNoplans": cmet.s41,
                                                            "OtherToday": cmet.s42,
                                                            "OtherYear": cmet.s43,
                                                            "OtherNoplans": cmet.s44,
                                                            "Commentary": cmet.s45,
                                                            "Help": cmet.s46,
                                                            "BeyondPolicy": cmet.s47
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "SocialImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "SocialImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "SocialImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "SocialImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22,
                            "varbool13": cmet.s23,
                            "varbool14": cmet.s24,
                            "varbool15": cmet.s25,
                            "varbool16": cmet.s26
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22,
                            "varbool13": cmet.s23,
                            "varbool14": cmet.s24,
                            "varbool15": cmet.s25,
                            "varbool16": cmet.s26
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "SocialImpact"]
                    newMet = {
                        "label": "SocialImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31,
                                                            "varbool1": cmet.s11,
                                                            "varbool2": cmet.s12,
                                                            "varbool3": cmet.s13,
                                                            "varbool4": cmet.s14,
                                                            "varbool5": cmet.s15,
                                                            "varbool6": cmet.s16,
                                                            "varbool7": cmet.s17,
                                                            "varbool8": cmet.s18,
                                                            "varbool9": cmet.s19,
                                                            "varbool10": cmet.s20,
                                                            "varbool11": cmet.s21,
                                                            "varbool12": cmet.s22,
                                                            "varbool13": cmet.s23,
                                                            "varbool14": cmet.s24,
                                                            "varbool15": cmet.s25,
                                                            "varbool16": cmet.s26
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "ImpactMeasure":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "ImpactMeasure"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "ImpactMeasure"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "ImpactMeasure"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "ImpactMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "ImpactMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "ImpactMeasure"]
                    newMet = {
                        "label": "ImpactMeasure",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "FinalPage":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "FinalPage"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "FinalPage"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "FinalPage"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "esgAnswer": cmet.m1,
                            "firstName": cmet.s1,
                            "lastName": cmet.s2
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "FinalPage",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "esgAnswer": cmet.m1,
                            "firstName": cmet.s1,
                            "lastName": cmet.s2
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "FinalPage",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "FinalPage"]
                    newMet = {
                        "label": "FinalPage",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "esgAnswer": cmet.m1,
                                                            "firstName": cmet.s1,
                                                            "lastName": cmet.s2
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "ActivateImpactQuestionnaireProgress":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [_item for _item in db_resultC["carbonmeasure"]
                              if _item["label"] != "Emissions"]

                    if ([_item for _item in db_resultC["carbonmeasure"] if _item["label"] == "Emissions"]):
                        emData = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] == "Emissions"][0]

                        if ([_item for _item in emData["metrics"] if _item["label"] == cmet.s5]):
                            yearData2C = [
                                _item for _item in emData["metrics"] if _item["label"] == cmet.s5][0]
                            if ([_item for _item in yearData2C["value"] if _item["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    _item for _item in yearData2C["value"] if _item["label"] != cmet.s6]
                                customMeasurement2C = []
                                customMeasurement2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [_item for _item in emData["metrics"]
                                           if _item["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            customMeasurement2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [_item for _item in emData["metrics"]
                                       if _item["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": customMeasurement2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [_item for _item in db_result["custommeasure"] if _item["label"] != "ActivateImpactQuestionnaireProgress"]

                if ([_item for _item in db_result["custommeasure"] if _item["label"] == "ActivateImpactQuestionnaireProgress"]):
                    remoteData = [_item for _item in db_result["custommeasure"] if _item["label"] == "ActivateImpactQuestionnaireProgress"][0]
                    if ([_item for _item in remoteData["metrics"] if _item["label"] == cmet.s5]):
                        yearData = [_item for _item in remoteData["metrics"]
                                    if _item["label"] == cmet.s5][0]
                        quarterData = [
                            _item for _item in yearData["value"] if _item["label"] != cmet.s6]
                        customMeasurement = []
                        customMeasurement.append({
                            'company-profile': cmet.s1,
                            'community-impact': cmet.s2,
                            'environmental-impact': cmet.s3,
                            'impact-and-esg-management': cmet.s4,
                            # Environment
                            'energy': cmet.s7,
                            "ghg-emissions-overview": cmet.s8,
                            "scope-1-emissions": cmet.s9,
                            "scope-2-emissions": cmet.s10,
                            "scope-3-emissions": cmet.s11,
                            # Employees
                            "company-employees": cmet.s12,
                            "employee-survey": cmet.s13,
                            "health-and-safety": cmet.s14,
                            "gender-diversity": cmet.s15,
                            "racial-diversity": cmet.s16,
                            # Governance
                            "corporate-governance": cmet.s17,
                            # Scope 2 intermediate progress
                            "scope-2-remote-workers": cmet.s18,
                            "scope-2-electricity": cmet.s19,
                            "scope-2-heat-and-steam": cmet.s20,
                            # Scope 3 intermediate progress
                            "scope-3-travel": cmet.s21,
                            "scope-3-commuting": cmet.s22,
                        })
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": customMeasurement
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "ActivateImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        customMeasurement = [{
                            'company-profile': cmet.s1,
                            'community-impact': cmet.s2,
                            'environmental-impact': cmet.s3,
                            'impact-and-esg-management': cmet.s4,
                            # Environment
                            'energy': cmet.s7,
                            "ghg-emissions-overview": cmet.s8,
                            "scope-1-emissions": cmet.s9,
                            "scope-2-emissions": cmet.s10,
                            "scope-3-emissions": cmet.s11,
                            # Employees
                            "company-employees": cmet.s12,
                            "employee-survey": cmet.s13,
                            "health-and-safety": cmet.s14,
                            "gender-diversity": cmet.s15,
                            "racial-diversity": cmet.s16,
                            # Governance
                            "corporate-governance": cmet.s17,
                            # Scope 2 intermediate progress
                            "scope-2-remote-workers": cmet.s18,
                            "scope-2-electricity": cmet.s19,
                            "scope-2-heat-and-steam": cmet.s20,
                            # Scope 3 intermediate progress
                            "scope-3-travel": cmet.s21,
                            "scope-3-commuting": cmet.s22,
                        }]
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "ActivateImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [_item for _item in db_result["custommeasure"]
                            if _item["label"] != "ActivateImpactQuestionnaireProgress"]
                    newMet = {
                        "label": "ActivateImpactQuestionnaireProgress",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            'company-profile': cmet.s1,
                                                            'community-impact': cmet.s2,
                                                            'environmental-impact': cmet.s3,
                                                            'impact-and-esg-management': cmet.s4,
                                                            # Environment
                                                            'energy': cmet.s7,
                                                            "ghg-emissions-overview": cmet.s8,
                                                            "scope-1-emissions": cmet.s9,
                                                            "scope-2-emissions": cmet.s10,
                                                            "scope-3-emissions": cmet.s11,
                                                            "skill-development": cmet.s12,
                                                            # Employees
                                                            "company-employees": cmet.s13,
                                                            "employee-survey": cmet.s14,
                                                            "health-and-safety": cmet.s14,
                                                            "gender-diversity": cmet.s15,
                                                            "racial-diversity": cmet.s16,
                                                            # Governance
                                                            "corporate-governance": cmet.s17,
                                                            # Scope 2 intermediate progress
                                                            "scope-2-remote-workers": cmet.s18,
                                                            "scope-2-electricity": cmet.s19,
                                                            "scope-2-heat-and-steam": cmet.s20,
                                                            # Scope 3 intermediate progress
                                                            "scope-3-travel": cmet.s21,
                                                            "scope-3-commuting": cmet.s22,
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

    else:
        pass


"""
Endpoint used to update the custom metrics for Activate measurement
"""
@customsroute.post('/custommeasurePiva')
async def custom_measure_piva(cmet: PivaMeasure):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "EnvironmentalImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "EnvironmentalImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "EnvironmentalImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "EnvironmentalImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "EnvironmentalImpact"]
                    newMet = {
                        "label": "EnvironmentalImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "GoalsMeasure":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "GoalsMeasure"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GoalsMeasure"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "GoalsMeasure"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GoalsMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GoalsMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "GoalsMeasure"]
                    newMet = {
                        "label": "GoalsMeasure",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "GovernanceImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "GovernanceImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "GovernanceImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "var1": cmet.s1,
                            "var2": cmet.s2
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "var1": cmet.s1,
                            "var2": cmet.s2
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "GovernanceImpact"]
                    newMet = {
                        "label": "GovernanceImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "SocialImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "SocialImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "SocialImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "SocialImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22,
                            "varbool13": cmet.s23,
                            "varbool14": cmet.s24,
                            "varbool15": cmet.s25,
                            "varbool16": cmet.s26
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22,
                            "varbool13": cmet.s23,
                            "varbool14": cmet.s24,
                            "varbool15": cmet.s25,
                            "varbool16": cmet.s26
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "SocialImpact"]
                    newMet = {
                        "label": "SocialImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31,
                                                            "varbool1": cmet.s11,
                                                            "varbool2": cmet.s12,
                                                            "varbool3": cmet.s13,
                                                            "varbool4": cmet.s14,
                                                            "varbool5": cmet.s15,
                                                            "varbool6": cmet.s16,
                                                            "varbool7": cmet.s17,
                                                            "varbool8": cmet.s18,
                                                            "varbool9": cmet.s19,
                                                            "varbool10": cmet.s20,
                                                            "varbool11": cmet.s21,
                                                            "varbool12": cmet.s22,
                                                            "varbool13": cmet.s23,
                                                            "varbool14": cmet.s24,
                                                            "varbool15": cmet.s25,
                                                            "varbool16": cmet.s26
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "PivaImpactQuestionnaireProgress":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [_item for _item in db_resultC["carbonmeasure"]
                              if _item["label"] != "Emissions"]

                    if ([_item for _item in db_resultC["carbonmeasure"] if _item["label"] == "Emissions"]):
                        emData = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] == "Emissions"][0]

                        if ([_item for _item in emData["metrics"] if _item["label"] == cmet.s5]):
                            yearData2C = [
                                _item for _item in emData["metrics"] if _item["label"] == cmet.s5][0]
                            if ([_item for _item in yearData2C["value"] if _item["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    _item for _item in yearData2C["value"] if _item["label"] != cmet.s6]
                                customMeasurement2C = []
                                customMeasurement2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [_item for _item in emData["metrics"]
                                           if _item["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            customMeasurement2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [_item for _item in emData["metrics"]
                                       if _item["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": customMeasurement2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [_item for _item in db_result["custommeasure"] if _item["label"] != "PivaImpactQuestionnaireProgress"]

                if ([_item for _item in db_result["custommeasure"] if _item["label"] == "PivaImpactQuestionnaireProgress"]):
                    remoteData = [_item for _item in db_result["custommeasure"] if _item["label"] == "PivaImpactQuestionnaireProgress"][0]
                    if ([_item for _item in remoteData["metrics"] if _item["label"] == cmet.s5]):
                        yearData = [_item for _item in remoteData["metrics"]
                                    if _item["label"] == cmet.s5][0]
                        quarterData = [
                            _item for _item in yearData["value"] if _item["label"] != cmet.s6]
                        customMeasurement = []
                        customMeasurement.append({
                            # Environment
                            "scope-1-emissions": cmet.s1,
                            "scope-2-emissions": cmet.s2,
                            # Social
                            "gender-diversity": cmet.s3,
                            "racial-diversity": cmet.s4,
                            "employee-relations": cmet.s7,
                            # Governance
                            "corporate-policy": cmet.s8,
                            "governance": cmet.s9,
                            # ESG Overview
                            "2022-achievements": cmet.s10,
                            "2023-goals": cmet.s11,
                            # Scope 2 intermediate keys
                            "scope-2-remote-workers": cmet.s12,
                            "scope-2-electricity": cmet.s13,
                            "scope-2-heat-and-steam": cmet.s14,

                            # Governance
                            "board-structure": cmet.s16,

                            # Environment Netzero
                            "net-zero":cmet.s17,

                            # Impact
                            "esg-improvement":cmet.s18,
                            "impact-overview":cmet.s19,
                        })
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": customMeasurement
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "PivaImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        customMeasurement = [{
                            # Environment
                            "scope-1-emissions": cmet.s1,
                            "scope-2-emissions": cmet.s2,
                            # Social
                            "gender-diversity": cmet.s3,
                            "racial-diversity": cmet.s4,
                            "employee-relations": cmet.s7,
                            # Governance
                            "corporate-policy": cmet.s8,
                            "governance": cmet.s9,
                            # ESG Overview
                            "2022-achievements": cmet.s10,
                            "2023-goals": cmet.s11,
                            # Scope 2 intermediate keys
                            "scope-2-remote-workers": cmet.s12,
                            "scope-2-electricity": cmet.s13,
                            "scope-2-heat-and-steam": cmet.s14,

                             # Governance
                            "board-structure": cmet.s16,

                            # Environment Netzero
                            "net-zero":cmet.s17,

                            # Impact
                            "esg-improvement":cmet.s18,
                            "impact-overview":cmet.s19,
                        }]
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "PivaImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [_item for _item in db_result["custommeasure"]
                            if _item["label"] != "PivaImpactQuestionnaireProgress"]
                    newMet = {
                        "label": "PivaImpactQuestionnaireProgress",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            # Environment
                                                            "scope-1-emissions": cmet.s1,
                                                            "scope-2-emissions": cmet.s2,
                                                            # Social
                                                            "gender-diversity": cmet.s3,
                                                            "racial-diversity": cmet.s4,
                                                            "employee-relations": cmet.s7,
                                                            # Governance
                                                            "corporate-policy": cmet.s8,
                                                            "governance": cmet.s9,
                                                            # ESG Overview
                                                            "2022-achievements": cmet.s10,
                                                            "2023-goals": cmet.s11,
                                                            # Scope 2 intermediate keys
                                                            "scope-2-remote-workers": cmet.s12,
                                                            "scope-2-electricity": cmet.s13,
                                                            "scope-2-heat-and-steam": cmet.s14,

                                                             # Governance
                                                            "board-structure": cmet.s16,

                                                            # Environment Netzero
                                                            "net-zero":cmet.s17,

                                                            # Impact
                                                            "esg-improvement":cmet.s18,
                                                            "impact-overview":cmet.s19,
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

    else:
        pass


"""
Endpoint used to update the custom metrics for Greenbacker measurement
"""
@customsroute.post('/custommeasureGreenbacker')
async def custom_measure_greenbacker(cmet: GreenbackerMeasure):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "EnvironmentalImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "EnvironmentalImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "EnvironmentalImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "EnvironmentalImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "EnvironmentalImpact"]
                    newMet = {
                        "label": "EnvironmentalImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "GoalsMeasure":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "GoalsMeasure"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GoalsMeasure"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "GoalsMeasure"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GoalsMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GoalsMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "GoalsMeasure"]
                    newMet = {
                        "label": "GoalsMeasure",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "GovernanceImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "GovernanceImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "GovernanceImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "GovernanceImpact"]
                    newMet = {
                        "label": "GovernanceImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9,
                                                            "var8": cmet.s10,
                                                            "var9": cmet.s11,
                                                            "var10": cmet.s12
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "CorporatePolicies":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "CorporatePolicies"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "CorporatePolicies"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "CorporatePolicies"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "bool17": cmet.m17,
                            "bool18": cmet.m18,
                            "bool19": cmet.m19,
                            "bool20": cmet.m20,
                            "bool21": cmet.m21,
                            "bool22": cmet.m22,
                            "bool23": cmet.m23,
                            "bool24": cmet.m24,
                            "bool25": cmet.m25,
                            "bool26": cmet.m26,
                            "bool27": cmet.m27,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "CorporatePolicies",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "bool17": cmet.m17,
                            "bool18": cmet.m18,
                            "bool19": cmet.m19,
                            "bool20": cmet.m20,
                            "bool21": cmet.m21,
                            "bool22": cmet.m22,
                            "bool23": cmet.m23,
                            "bool24": cmet.m24,
                            "bool25": cmet.m25,
                            "bool26": cmet.m26,
                            "bool27": cmet.m27,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "CorporatePolicies",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "CorporatePolicies"]
                    newMet = {
                        "label": "CorporatePolicies",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "bool17": cmet.m17,
                                                            "bool18": cmet.m18,
                                                            "bool19": cmet.m19,
                                                            "bool20": cmet.m20,
                                                            "bool21": cmet.m21,
                                                            "bool22": cmet.m22,
                                                            "bool23": cmet.m23,
                                                            "bool24": cmet.m24,
                                                            "bool25": cmet.m25,
                                                            "bool26": cmet.m26,
                                                            "bool27": cmet.m27,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9,
                                                            "var8": cmet.s10,
                                                            "var9": cmet.s11,
                                                            "var10": cmet.s12
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "EnergyImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "EnergyImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "EnergyImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "EnergyImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "bool17": cmet.m17,
                            "bool18": cmet.m18,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14,
                            "var13": cmet.s15,
                            "var14": cmet.s16,
                            "var15": cmet.s17,
                            "var16": cmet.s18,
                            "var17": cmet.s19,
                            "var18": cmet.s20,
                            "var19": cmet.s21,
                            "var20": cmet.s22,
                            "var21": cmet.s23,
                            "var22": cmet.s24,
                            "var23": cmet.s25,
                            "var24": cmet.s26,
                            "var25": cmet.s27,
                            "var26": cmet.s28,
                            "var27": cmet.s29,
                            "var28": cmet.s30,
                            "var29": cmet.s31,
                            "var30": cmet.s32,
                            "var31": cmet.s33,
                            "var32": cmet.s34,
                            "var33": cmet.s35,
                            "var34": cmet.s36,
                            "var35": cmet.s37,
                            "var36": cmet.s38,
                            "var37": cmet.s39,
                            "var38": cmet.s40,
                            "var39": cmet.s41,
                            "var40": cmet.s42,
                            "var41": cmet.s43,
                            "var42": cmet.s44,
                            "var43": cmet.s45,
                            "var44": cmet.s46,
                            "var45": cmet.s47,
                            "var46": cmet.s48,
                            "var47": cmet.s49,
                            "var48": cmet.s50,
                            "var49": cmet.s51,
                            "var50": cmet.s52,
                            "var51": cmet.s53
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "EnergyImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "bool17": cmet.m17,
                            "bool18": cmet.m18,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14,
                            "var13": cmet.s15,
                            "var14": cmet.s16,
                            "var15": cmet.s17,
                            "var16": cmet.s18,
                            "var17": cmet.s19,
                            "var18": cmet.s20,
                            "var19": cmet.s21,
                            "var20": cmet.s22,
                            "var21": cmet.s23,
                            "var22": cmet.s24,
                            "var23": cmet.s25,
                            "var24": cmet.s26,
                            "var25": cmet.s27,
                            "var26": cmet.s28,
                            "var27": cmet.s29,
                            "var28": cmet.s30,
                            "var29": cmet.s31,
                            "var30": cmet.s32,
                            "var31": cmet.s33,
                            "var32": cmet.s34,
                            "var33": cmet.s35,
                            "var34": cmet.s36,
                            "var35": cmet.s37,
                            "var36": cmet.s38,
                            "var37": cmet.s39,
                            "var38": cmet.s40,
                            "var39": cmet.s41,
                            "var40": cmet.s42,
                            "var41": cmet.s43,
                            "var42": cmet.s44,
                            "var43": cmet.s45,
                            "var44": cmet.s46,
                            "var45": cmet.s47,
                            "var46": cmet.s48,
                            "var47": cmet.s49,
                            "var48": cmet.s50,
                            "var49": cmet.s51,
                            "var50": cmet.s52,
                            "var51": cmet.s53
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "EnergyImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "EnergyImpact"]
                    newMet = {
                        "label": "EnergyImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "bool17": cmet.m17,
                                                            "bool18": cmet.m18,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9,
                                                            "var8": cmet.s10,
                                                            "var9": cmet.s11,
                                                            "var10": cmet.s12,
                                                            "var11": cmet.s13,
                                                            "var12": cmet.s14,
                                                            "var13": cmet.s15,
                                                            "var14": cmet.s16,
                                                            "var15": cmet.s17,
                                                            "var16": cmet.s18,
                                                            "var17": cmet.s19,
                                                            "var18": cmet.s20,
                                                            "var19": cmet.s21,
                                                            "var20": cmet.s22,
                                                            "var21": cmet.s23,
                                                            "var22": cmet.s24,
                                                            "var23": cmet.s25,
                                                            "var24": cmet.s26,
                                                            "var25": cmet.s27,
                                                            "var26": cmet.s28,
                                                            "var27": cmet.s29,
                                                            "var28": cmet.s30,
                                                            "var29": cmet.s31,
                                                            "var30": cmet.s32,
                                                            "var31": cmet.s33,
                                                            "var32": cmet.s34,
                                                            "var33": cmet.s35,
                                                            "var34": cmet.s36,
                                                            "var35": cmet.s37,
                                                            "var36": cmet.s38,
                                                            "var37": cmet.s39,
                                                            "var38": cmet.s40,
                                                            "var39": cmet.s41,
                                                            "var40": cmet.s42,
                                                            "var41": cmet.s43,
                                                            "var42": cmet.s44,
                                                            "var43": cmet.s45,
                                                            "var44": cmet.s46,
                                                            "var45": cmet.s47,
                                                            "var46": cmet.s48,
                                                            "var47": cmet.s49,
                                                            "var48": cmet.s50,
                                                            "var49": cmet.s51,
                                                            "var50": cmet.s52,
                                                            "var51": cmet.s53
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "TCFDEnvironment":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "TCFDEnvironment"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "TCFDEnvironment"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "TCFDEnvironment"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "TCFDEnvironment",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "TCFDEnvironment",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "TCFDEnvironment"]
                    newMet = {
                        "label": "TCFDEnvironment",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "GreenbackerImpactQuestionnaireProgress":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [_item for _item in db_resultC["carbonmeasure"]
                              if _item["label"] != "Emissions"]

                    if ([_item for _item in db_resultC["carbonmeasure"] if _item["label"] == "Emissions"]):
                        emData = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] == "Emissions"][0]

                        if ([_item for _item in emData["metrics"] if _item["label"] == cmet.s5]):
                            yearData2C = [
                                _item for _item in emData["metrics"] if _item["label"] == cmet.s5][0]
                            if ([_item for _item in yearData2C["value"] if _item["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    _item for _item in yearData2C["value"] if _item["label"] != cmet.s6]
                                customMeasurement2C = []
                                customMeasurement2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [_item for _item in emData["metrics"]
                                           if _item["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            customMeasurement2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [_item for _item in emData["metrics"]
                                       if _item["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": customMeasurement2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [_item for _item in db_result["custommeasure"] if _item["label"] != "GreenbackerImpactQuestionnaireProgress"]

                if ([_item for _item in db_result["custommeasure"] if _item["label"] == "GreenbackerImpactQuestionnaireProgress"]):
                    remoteData = [_item for _item in db_result["custommeasure"] if _item["label"] == "GreenbackerImpactQuestionnaireProgress"][0]
                    if ([_item for _item in remoteData["metrics"] if _item["label"] == cmet.s5]):
                        yearData = [_item for _item in remoteData["metrics"]
                                    if _item["label"] == cmet.s5][0]
                        quarterData = [
                            _item for _item in yearData["value"] if _item["label"] != cmet.s6]
                        customMeasurement = []
                        customMeasurement.append({
                            # Environment
                            "environmental-performance": cmet.s1,
                            "environmental-impact": cmet.s2,
                            "ghg-emissions": cmet.s3,
                            # Social
                            "social-performance": cmet.s4,
                            "health-and-safety": cmet.s7,
                            "employee-overview": cmet.s8,
                            "gender-diversity": cmet.s9,
                            "racial-diversity": cmet.s10,
                            # Governance
                            "governance-overview": cmet.s11,
                            "corporate-policy": cmet.s12,
                            # Scope emissions
                            "scope-1-emissions": cmet.s13,
                            "scope-2-emissions": cmet.s14,
                            # Scope 2 intermediate progress
                            "scope-2-remote-workers": cmet.s15,
                            "scope-2-electricity": cmet.s16,
                            "scope-2-heat-and-steam": cmet.s17,
                            "scope-3-emissions": cmet.s18,
                            # Scope 3 intermediate progress
                            "scope-3-travel": cmet.s19,
                            "scope-3-commuting": cmet.s20,
                            "scope-3-cloud": cmet.s21,
                            "tcfd": cmet.s22,
                        })
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": customMeasurement
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GreenbackerImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        customMeasurement = [{
                            # Environment
                            "environmental-performance": cmet.s1,
                            "environmental-impact": cmet.s2,
                            "ghg-emissions": cmet.s3,
                            # Social
                            "social-performance": cmet.s4,
                            "health-and-safety": cmet.s7,
                            "employee-overview": cmet.s8,
                            "gender-diversity": cmet.s9,
                            "racial-diversity": cmet.s10,
                            # Governance
                            "governance-overview": cmet.s11,
                            "corporate-policy": cmet.s12,
                            # Scope emissions
                            "scope-1-emissions": cmet.s13,
                            "scope-2-emissions": cmet.s14,
                            # Scope 2 intermediate progress
                            "scope-2-remote-workers": cmet.s15,
                            "scope-2-electricity": cmet.s16,
                            "scope-2-heat-and-steam": cmet.s17,
                            "scope-3-emissions": cmet.s18,
                            # Scope 3 intermediate progress
                            "scope-3-travel": cmet.s19,
                            "scope-3-commuting": cmet.s20,
                            "scope-3-cloud": cmet.s21,
                            "tcfd": cmet.s22,
                            }]
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GreenbackerImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [_item for _item in db_result["custommeasure"]
                            if _item["label"] != "GreenbackerImpactQuestionnaireProgress"]
                    newMet = {
                        "label": "GreenbackerImpactQuestionnaireProgress",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            # Environment
                                                            "environmental-performance": cmet.s1,
                                                            "environmental-impact": cmet.s2,
                                                            "ghg-emissions": cmet.s3,
                                                            # Social
                                                            "social-performance": cmet.s4,
                                                            "health-and-safety": cmet.s7,
                                                            "employee-overview": cmet.s8,
                                                            "gender-diversity": cmet.s9,
                                                            "racial-diversity": cmet.s10,
                                                            #  Governance
                                                            "governance-overview": cmet.s11,
                                                            "corporate-policy": cmet.s12,
                                                            # Scope emissions
                                                            "scope-1-emissions": cmet.s13,
                                                            "scope-2-emissions": cmet.s14,
                                                            # Scope 2 intermediate progress
                                                            "scope-2-remote-workers": cmet.s15,
                                                            "scope-2-electricity": cmet.s16,
                                                            "scope-2-heat-and-steam": cmet.s17,
                                                            "scope-3-emissions": cmet.s18,
                                                            # Scope 3 intermediate progress
                                                            "scope-3-travel": cmet.s19,
                                                            "scope-3-commuting": cmet.s20,
                                                            "scope-3-cloud": cmet.s21,
                                                            "tcfd": cmet.s22,
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "SocialImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "SocialImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "SocialImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "SocialImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22,
                            "varbool13": cmet.s23,
                            "varbool14": cmet.s24,
                            "varbool15": cmet.s25,
                            "varbool16": cmet.s26
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31,
                            "varbool1": cmet.s11,
                            "varbool2": cmet.s12,
                            "varbool3": cmet.s13,
                            "varbool4": cmet.s14,
                            "varbool5": cmet.s15,
                            "varbool6": cmet.s16,
                            "varbool7": cmet.s17,
                            "varbool8": cmet.s18,
                            "varbool9": cmet.s19,
                            "varbool10": cmet.s20,
                            "varbool11": cmet.s21,
                            "varbool12": cmet.s22,
                            "varbool13": cmet.s23,
                            "varbool14": cmet.s24,
                            "varbool15": cmet.s25,
                            "varbool16": cmet.s26
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "SocialImpact"]
                    newMet = {
                        "label": "SocialImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31,
                                                            "varbool1": cmet.s11,
                                                            "varbool2": cmet.s12,
                                                            "varbool3": cmet.s13,
                                                            "varbool4": cmet.s14,
                                                            "varbool5": cmet.s15,
                                                            "varbool6": cmet.s16,
                                                            "varbool7": cmet.s17,
                                                            "varbool8": cmet.s18,
                                                            "varbool9": cmet.s19,
                                                            "varbool10": cmet.s20,
                                                            "varbool11": cmet.s21,
                                                            "varbool12": cmet.s22,
                                                            "varbool13": cmet.s23,
                                                            "varbool14": cmet.s24,
                                                            "varbool15": cmet.s25,
                                                            "varbool16": cmet.s26
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)


    else:
        pass



@customsroute.post("/fileuploadCBIV")
async def upload_files(
    oid: str = Form(...),
    email: str = Form(...),
    metric: str = Form(...),
    fileKPIs: Optional[UploadFile] = File(None),
    fileHumanRights: Optional[UploadFile] = File(None),
    fileAntiCorruption: Optional[UploadFile] = File(None),
    fileEthics: Optional[UploadFile] = File(None),
    fileDEI: Optional[UploadFile] = File(None),
    fileESG: Optional[UploadFile] = File(None),
    fileOthers: Optional[UploadFile] = File(None),
    filePublications: Optional[UploadFile] = File(None),
    fileDocs: Optional[UploadFile] = File(None),
    fileWhistleblower: Optional[UploadFile] = File(None),
    fileSupplier: Optional[UploadFile] = File(None),
    fileAccidentPrevention: Optional[UploadFile] = File(None),
    fileHumanTrafficking: Optional[UploadFile] = File(None),
    fileDueDiligence: Optional[UploadFile] = File(None),
    fileMonitorCompliance: Optional[UploadFile] = File(None),
    s5: str = Form(...),
    s6: str = Form(...)
):
    files = [
        ("fileKPIs", fileKPIs),
        ("fileHumanRights", fileHumanRights),
        ("fileAntiCorruption", fileAntiCorruption),
        ("fileEthics", fileEthics),
        ("fileDEI", fileDEI),
        ("fileESG", fileESG),
        ("fileOthers", fileOthers),
        ("filePublications", filePublications),
        ("fileDocs", fileDocs),
        ("fileWhistleblower", fileWhistleblower),
        ("fileSupplier", fileSupplier),
        ("fileAccidentPrevention", fileAccidentPrevention),
        ("fileHumanTrafficking", fileHumanTrafficking),
        ("fileDueDiligence", fileDueDiligence),
        ("fileMonitorCompliance", fileMonitorCompliance)
    ]

    defaultFilesSchema = {
        "kpi": {"file_name": " ", "file_url": " "},
        "humanRights": {"file_name": " ", "file_url": " "},
        "antiCorruption": {"file_name": " ", "file_url": " "},
        "ethics": {"file_name": " ", "file_url": " "},
        "dei": {"file_name": " ", "file_url": " "},
        "esg": {"file_name": " ", "file_url": " "},
        "others": {"file_name": " ", "file_url": " "},
        "publications": {"file_name": " ", "file_url": " "},
        "docs": {"file_name": " ", "file_url": " "},
        "whistleblower": {"file_name": " ", "file_url": " "},
        "supplier": {"file_name": " ", "file_url": " "},
        "accidentPrevention": {"file_name": " ", "file_url": " "},
        "humanTrafficking": {"file_name": " ", "file_url": " "},
        "dueDiligence": {"file_name": " ", "file_url": " "},
        "monitorCompliance": {"file_name": " ", "file_url": " "}
    }
    
    existingCurrYrQtrFiles = get_files(oid, email, s5, s6, metric)

    if existingCurrYrQtrFiles:
        existingFiles = existingCurrYrQtrFiles
    else:
        # getting from past year and quarter
        existingFiles = get_year_qtr_files_data(oid, email, s5, s6, metric, defaultFilesSchema.keys())

    # if existingFiles:
    #     uploadedFiles = existingFiles

    #     # checking for missing keys in existing data
    #     for k,v in defaultFilesSchema.items():
    #         if k not in uploadedFiles:
    #             uploadedFiles[k] = v
    # else:
    #     uploadedFiles = defaultFilesSchema
    
    # creates a dict based on default file schema and existing files
    uploadedFiles = {**defaultFilesSchema, **(existingFiles or {})}

    if fileKPIs:
        uploadedFiles["kpi"] = upload_to_azure_blob(fileKPIs)
    if fileHumanRights:
        uploadedFiles["humanRights"] = upload_to_azure_blob(fileHumanRights)
    if fileAntiCorruption:
        uploadedFiles["antiCorruption"] = upload_to_azure_blob(fileAntiCorruption)
    if fileEthics:
        uploadedFiles["ethics"] = upload_to_azure_blob(fileEthics)
    if fileDEI:
        uploadedFiles["dei"] = upload_to_azure_blob(fileDEI)
    if fileESG:
        uploadedFiles["esg"] = upload_to_azure_blob(fileESG)
    if fileOthers:
        uploadedFiles["others"] = upload_to_azure_blob(fileOthers)
    if filePublications:
        uploadedFiles["publications"] = upload_to_azure_blob(filePublications)
    if fileDocs:
        uploadedFiles["docs"] = upload_to_azure_blob(fileDocs)
    if fileWhistleblower:
        uploadedFiles["whistleblower"] = upload_to_azure_blob(fileWhistleblower)
    if fileSupplier:
        uploadedFiles["supplier"] = upload_to_azure_blob(fileSupplier)
    if fileAccidentPrevention:
        uploadedFiles["accidentPrevention"] = upload_to_azure_blob(fileAccidentPrevention)
    if fileHumanTrafficking:
        uploadedFiles["humanTrafficking"] = upload_to_azure_blob(fileHumanTrafficking)
    if fileDueDiligence:
        uploadedFiles["dueDiligence"] = upload_to_azure_blob(fileDueDiligence)
    if fileMonitorCompliance:
        uploadedFiles["monitorCompliance"] = upload_to_azure_blob(fileMonitorCompliance)



    db_result = False
    try:
        db_result = read_item(callConnect.container15, oid, email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('read_item failed for /fileuploadCBIV')
        if not db_result:
            return {"status": "error", "message": "Could not fetch item from database"}
        pass

    if db_result:
        if "custommeasure" in db_result:
            if metric:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                mets = [z for z in db_result["custommeasure"] if z["label"] != metric]
                if ([z for z in db_result["custommeasure"] if z["label"] == metric]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == metric][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != s6]
                        cmeas = []
                        cmeas.append({
                            "kpi": {"file_name": uploadedFiles["kpi"]["file_name"], "file_url": uploadedFiles["kpi"]["file_url"]},
                            "humanRights": {"file_name": uploadedFiles["humanRights"]["file_name"], "file_url": uploadedFiles["humanRights"]["file_url"]},
                            "antiCorruption": {"file_name": uploadedFiles["antiCorruption"]["file_name"], "file_url": uploadedFiles["antiCorruption"]["file_url"]},
                            "ethics": {"file_name": uploadedFiles["ethics"]["file_name"], "file_url": uploadedFiles["ethics"]["file_url"]},
                            "dei": {"file_name": uploadedFiles["dei"]["file_name"], "file_url": uploadedFiles["dei"]["file_url"]},
                            "esg": {"file_name": uploadedFiles["esg"]["file_name"], "file_url": uploadedFiles["esg"]["file_url"]},
                            "others": {"file_name": uploadedFiles["others"]["file_name"], "file_url": uploadedFiles["others"]["file_url"]},
                            "publications": {"file_name": uploadedFiles["publications"]["file_name"], "file_url": uploadedFiles["publications"]["file_url"]},
                            "docs": {"file_name": uploadedFiles["docs"]["file_name"], "file_url": uploadedFiles["docs"]["file_url"]},
                            "whistleblower": {"file_name": uploadedFiles["whistleblower"]["file_name"], "file_url": uploadedFiles["whistleblower"]["file_url"]},
                            "supplier": {"file_name": uploadedFiles["supplier"]["file_name"], "file_url": uploadedFiles["supplier"]["file_url"]},
                            "accidentPrevention": {"file_name": uploadedFiles["accidentPrevention"]["file_name"], "file_url": uploadedFiles["accidentPrevention"]["file_url"]},
                            "humanTrafficking": {"file_name": uploadedFiles["humanTrafficking"]["file_name"], "file_url": uploadedFiles["humanTrafficking"]["file_url"]},
                            "dueDiligence": {"file_name": uploadedFiles["dueDiligence"]["file_name"], "file_url": uploadedFiles["dueDiligence"]["file_url"]},
                            "monitorCompliance": {"file_name": uploadedFiles["monitorCompliance"]["file_name"], "file_url": uploadedFiles["monitorCompliance"]["file_url"]}
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != s5]
                        quarterData.append({
                            "label": s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": metric,
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                        return {"status": "success", "message": f"File added successfully to user {email}"}
                    else:
                        cmeas = [{
                           "kpi": {"file_name": uploadedFiles["kpi"]["file_name"], "file_url": uploadedFiles["kpi"]["file_url"]},
                            "humanRights": {"file_name": uploadedFiles["humanRights"]["file_name"], "file_url": uploadedFiles["humanRights"]["file_url"]},
                            "antiCorruption": {"file_name": uploadedFiles["antiCorruption"]["file_name"], "file_url": uploadedFiles["antiCorruption"]["file_url"]},
                            "ethics": {"file_name": uploadedFiles["ethics"]["file_name"], "file_url": uploadedFiles["ethics"]["file_url"]},
                            "dei": {"file_name": uploadedFiles["dei"]["file_name"], "file_url": uploadedFiles["dei"]["file_url"]},
                            "esg": {"file_name": uploadedFiles["esg"]["file_name"], "file_url": uploadedFiles["esg"]["file_url"]},
                            "others": {"file_name": uploadedFiles["others"]["file_name"], "file_url": uploadedFiles["others"]["file_url"]},
                            "publications": {"file_name": uploadedFiles["publications"]["file_name"], "file_url": uploadedFiles["publications"]["file_url"]},
                            "docs": {"file_name": uploadedFiles["docs"]["file_name"], "file_url": uploadedFiles["docs"]["file_url"]},
                            "whistleblower": {"file_name": uploadedFiles["whistleblower"]["file_name"], "file_url": uploadedFiles["whistleblower"]["file_url"]},
                            "supplier": {"file_name": uploadedFiles["supplier"]["file_name"], "file_url": uploadedFiles["supplier"]["file_url"]},
                            "accidentPrevention": {"file_name": uploadedFiles["accidentPrevention"]["file_name"], "file_url": uploadedFiles["accidentPrevention"]["file_url"]},
                            "humanTrafficking": {"file_name": uploadedFiles["humanTrafficking"]["file_name"], "file_url": uploadedFiles["humanTrafficking"]["file_url"]},
                            "dueDiligence": {"file_name": uploadedFiles["dueDiligence"]["file_name"], "file_url": uploadedFiles["dueDiligence"]["file_url"]},
                            "monitorCompliance": {"file_name": uploadedFiles["monitorCompliance"]["file_name"], "file_url": uploadedFiles["monitorCompliance"]["file_url"]}
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != s5]
                        tmeas.append({
                            "label": s5,
                            "value": [
                                {
                                    "label": s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": metric,
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                        return {"status": "success", "message": f"File added successfully to user {email}"}

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != metric]
                    newMet = {
                        "label": metric,
                        "metrics": [
                            {
                                "label": s5,
                                "value": [
                                    {
                                        "label": s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "kpi": {"file_name": uploadedFiles["kpi"]["file_name"], "file_url": uploadedFiles["kpi"]["file_url"]},
                                                            "humanRights": {"file_name": uploadedFiles["humanRights"]["file_name"], "file_url": uploadedFiles["humanRights"]["file_url"]},
                                                            "antiCorruption": {"file_name": uploadedFiles["antiCorruption"]["file_name"], "file_url": uploadedFiles["antiCorruption"]["file_url"]},
                                                            "ethics": {"file_name": uploadedFiles["ethics"]["file_name"], "file_url": uploadedFiles["ethics"]["file_url"]},
                                                            "dei": {"file_name": uploadedFiles["dei"]["file_name"], "file_url": uploadedFiles["dei"]["file_url"]},
                                                            "esg": {"file_name": uploadedFiles["esg"]["file_name"], "file_url": uploadedFiles["esg"]["file_url"]},
                                                            "others": {"file_name": uploadedFiles["others"]["file_name"], "file_url": uploadedFiles["others"]["file_url"]},
                                                            "publications": {"file_name": uploadedFiles["publications"]["file_name"], "file_url": uploadedFiles["publications"]["file_url"]},
                                                            "docs": {"file_name": uploadedFiles["docs"]["file_name"], "file_url": uploadedFiles["docs"]["file_url"]},
                                                            "whistleblower": {"file_name": uploadedFiles["whistleblower"]["file_name"], "file_url": uploadedFiles["whistleblower"]["file_url"]},
                                                            "supplier": {"file_name": uploadedFiles["supplier"]["file_name"], "file_url": uploadedFiles["supplier"]["file_url"]},
                                                            "accidentPrevention": {"file_name": uploadedFiles["accidentPrevention"]["file_name"], "file_url": uploadedFiles["accidentPrevention"]["file_url"]},
                                                            "humanTrafficking": {"file_name": uploadedFiles["humanTrafficking"]["file_name"], "file_url": uploadedFiles["humanTrafficking"]["file_url"]},
                                                            "dueDiligence": {"file_name": uploadedFiles["dueDiligence"]["file_name"], "file_url": uploadedFiles["dueDiligence"]["file_url"]},
                                                            "monitorCompliance": {"file_name": uploadedFiles["monitorCompliance"]["file_name"], "file_url": uploadedFiles["monitorCompliance"]["file_url"]}
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                    return {"status": "success", "message": f"File added successfully to user {email}"}
    else:
        pass



@customsroute.post("/fileuploadKNIGHT")
async def upload_files(oid: str = Form(...), email: str = Form(...), metric: str = Form(...), fileEthics: Optional[UploadFile] = File(None), fileESG: Optional[UploadFile] = File(None), s5: str = Form(...), s6: str = Form(...)):
    existingFiles = get_files(oid, email, s5, s6, metric)
    
    if existingFiles:
        uploadedFiles = existingFiles
    else:
        # Check each possible file
        uploadedFiles = {
            "ethics": {"file_name": " ", "file_url": " "},
            "esg": {"file_name": " ", "file_url": " "}
        }

    
    if fileEthics:
        uploadedFiles["ethics"] = upload_to_azure_blob(fileEthics)
    if fileESG:
        uploadedFiles["esg"] = upload_to_azure_blob(fileESG)



    db_result = False
    try:
        db_result = read_item(callConnect.container15, oid, email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('read_item failed for /fileuploadKNIGHT')
        if not db_result:
            return {"status": "error", "message": "Could not fetch item from database"}
        pass

    if db_result:
        if "custommeasure" in db_result:
            if metric:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                mets = [z for z in db_result["custommeasure"] if z["label"] != metric]
                if ([z for z in db_result["custommeasure"] if z["label"] == metric]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == metric][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != s6]
                        cmeas = []
                        cmeas.append({
                            "ethics": {"file_name": uploadedFiles["ethics"]["file_name"], "file_url": uploadedFiles["ethics"]["file_url"]},
                            "esg": {"file_name": uploadedFiles["esg"]["file_name"], "file_url": uploadedFiles["esg"]["file_url"]}
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != s5]
                        quarterData.append({
                            "label": s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": metric,
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                        return {"status": "success", "message": f"File added successfully to user {email}"}
                    else:
                        cmeas = [{
                            "ethics": {"file_name": uploadedFiles["ethics"]["file_name"], "file_url": uploadedFiles["ethics"]["file_url"]},
                            "esg": {"file_name": uploadedFiles["esg"]["file_name"], "file_url": uploadedFiles["esg"]["file_url"]}
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != s5]
                        tmeas.append({
                            "label": s5,
                            "value": [
                                {
                                    "label": s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": metric,
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                        return {"status": "success", "message": f"File added successfully to user {email}"}

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != metric]
                    newMet = {
                        "label": metric,
                        "metrics": [
                            {
                                "label": s5,
                                "value": [
                                    {
                                        "label": s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "ethics": {"file_name": uploadedFiles["ethics"]["file_name"], "file_url": uploadedFiles["ethics"]["file_url"]},
                                                            "esg": {"file_name": uploadedFiles["esg"]["file_name"], "file_url": uploadedFiles["esg"]["file_url"]}
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                    return {"status": "success", "message": f"File added successfully to user {email}"}
    else:
        pass


"""
Endpoint used to update the custom metrics for CBIV measurement
"""
@customsroute.post('/custommeasureCBIV')
async def custom_measure_CBIV(cmet: CBIVMeasure):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "EnvironmentalImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "EnvironmentalImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "EnvironmentalImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "EnvironmentalImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s11,
                            "var12": cmet.s12,
                            "var13": cmet.s13,
                            "var14": cmet.s14,
                            "var15": cmet.s15,
                            "var16": cmet.s16,
                            "var17": cmet.s17,
                            "var18": cmet.s18
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s11,
                            "var12": cmet.s12,
                            "var13": cmet.s13,
                            "var14": cmet.s14,
                            "var15": cmet.s15,
                            "var16": cmet.s16,
                            "var17": cmet.s17,
                            "var18": cmet.s18
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "EnvironmentalImpact"]
                    newMet = {
                        "label": "EnvironmentalImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s11,
                                                            "var12": cmet.s12,
                                                            "var13": cmet.s13,
                                                            "var14": cmet.s14,
                                                            "var15": cmet.s15,
                                                            "var16": cmet.s16,
                                                            "var17": cmet.s17,
                                                            "var18": cmet.s18
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "GoalsMeasure":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "GoalsMeasure"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GoalsMeasure"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "GoalsMeasure"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GoalsMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GoalsMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "GoalsMeasure"]
                    newMet = {
                        "label": "GoalsMeasure",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "GovernanceImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "GovernanceImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "bool17": cmet.m17,
                            "bool18": cmet.m18,
                            "bool19": cmet.m19,
                            "bool20": cmet.m20,
                            "bool21": cmet.m21,
                            "bool22": cmet.m22,
                            "bool23": cmet.m23,
                            "bool24": cmet.m24,
                            "bool25": cmet.m25,
                            "bool26": cmet.m26,
                            "bool27": cmet.m27,
                            "bool28": cmet.m28,
                            "bool29": cmet.m29,
                            "bool30": cmet.m30,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "bool17": cmet.m17,
                            "bool18": cmet.m18,
                            "bool19": cmet.m19,
                            "bool20": cmet.m20,
                            "bool21": cmet.m21,
                            "bool22": cmet.m22,
                            "bool23": cmet.m23,
                            "bool24": cmet.m24,
                            "bool25": cmet.m25,
                            "bool26": cmet.m26,
                            "bool27": cmet.m27,
                            "bool28": cmet.m28,
                            "bool29": cmet.m29,
                            "bool30": cmet.m30,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "GovernanceImpact"]
                    newMet = {
                        "label": "GovernanceImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "bool17": cmet.m17,
                                                            "bool18": cmet.m18,
                                                            "bool19": cmet.m19,
                                                            "bool20": cmet.m20,
                                                            "bool21": cmet.m21,
                                                            "bool22": cmet.m22,
                                                            "bool23": cmet.m23,
                                                            "bool24": cmet.m24,
                                                            "bool25": cmet.m25,
                                                            "bool26": cmet.m26,
                                                            "bool27": cmet.m27,
                                                            "bool28": cmet.m28,
                                                            "bool29": cmet.m29,
                                                            "bool30": cmet.m30,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "CorporatePolicies":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "CorporatePolicies"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "CorporatePolicies"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "CorporatePolicies"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "bool17": cmet.m17,
                            "bool18": cmet.m18,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "CorporatePolicies",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "bool17": cmet.m17,
                            "bool18": cmet.m18,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "CorporatePolicies",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "CorporatePolicies"]
                    newMet = {
                        "label": "CorporatePolicies",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "bool17": cmet.m17,
                                                            "bool18": cmet.m18,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9,
                                                            "var8": cmet.s10,
                                                            "var9": cmet.s11,
                                                            "var10": cmet.s12
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "EnergyImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "EnergyImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "EnergyImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "EnergyImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14,
                            "var13": cmet.s15,
                            "var14": cmet.s16,
                            "var15": cmet.s17,
                            "var16": cmet.s18,
                            "var17": cmet.s19,
                            "var18": cmet.s20,
                            "var19": cmet.s21,
                            "var20": cmet.s22,
                            "var21": cmet.s23,
                            "var22": cmet.s24,
                            "var23": cmet.s25,
                            "var24": cmet.s26,
                            "var25": cmet.s27,
                            "var26": cmet.s28,
                            "var27": cmet.s29,
                            "var28": cmet.s30,
                            "var29": cmet.s31,
                            "var30": cmet.s32,
                            "var31": cmet.s33,
                            "var32": cmet.s34,
                            "var33": cmet.s35,
                            "var34": cmet.s36,
                            "var35": cmet.s37,
                            "var36": cmet.s38,
                            "var37": cmet.s39,
                            "var38": cmet.s40,
                            "var39": cmet.s41,
                            "var40": cmet.s42,
                            "var41": cmet.s43,
                            "var42": cmet.s44,
                            "var43": cmet.s45,
                            "var44": cmet.s46,
                            "var45": cmet.s47,
                            "var46": cmet.s48
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "EnergyImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14,
                            "var13": cmet.s15,
                            "var14": cmet.s16,
                            "var15": cmet.s17,
                            "var16": cmet.s18,
                            "var17": cmet.s19,
                            "var18": cmet.s20,
                            "var19": cmet.s21,
                            "var20": cmet.s22,
                            "var21": cmet.s23,
                            "var22": cmet.s24,
                            "var23": cmet.s25,
                            "var24": cmet.s26,
                            "var25": cmet.s27,
                            "var26": cmet.s28,
                            "var27": cmet.s29,
                            "var28": cmet.s30,
                            "var29": cmet.s31,
                            "var30": cmet.s32,
                            "var31": cmet.s33,
                            "var32": cmet.s34,
                            "var33": cmet.s35,
                            "var34": cmet.s36,
                            "var35": cmet.s37,
                            "var36": cmet.s38,
                            "var37": cmet.s39,
                            "var38": cmet.s40,
                            "var39": cmet.s41,
                            "var40": cmet.s42,
                            "var41": cmet.s43,
                            "var42": cmet.s44,
                            "var43": cmet.s45,
                            "var44": cmet.s46,
                            "var45": cmet.s47,
                            "var46": cmet.s48
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "EnergyImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "EnergyImpact"]
                    newMet = {
                        "label": "EnergyImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9,
                                                            "var8": cmet.s10,
                                                            "var9": cmet.s11,
                                                            "var10": cmet.s12,
                                                            "var11": cmet.s13,
                                                            "var12": cmet.s14,
                                                            "var13": cmet.s15,
                                                            "var14": cmet.s16,
                                                            "var15": cmet.s17,
                                                            "var16": cmet.s18,
                                                            "var17": cmet.s19,
                                                            "var18": cmet.s20,
                                                            "var19": cmet.s21,
                                                            "var20": cmet.s22,
                                                            "var21": cmet.s23,
                                                            "var22": cmet.s24,
                                                            "var23": cmet.s25,
                                                            "var24": cmet.s26,
                                                            "var25": cmet.s27,
                                                            "var26": cmet.s28,
                                                            "var27": cmet.s29,
                                                            "var28": cmet.s30,
                                                            "var29": cmet.s31,
                                                            "var30": cmet.s32,
                                                            "var31": cmet.s33,
                                                            "var32": cmet.s34,
                                                            "var33": cmet.s35,
                                                            "var34": cmet.s36,
                                                            "var35": cmet.s37,
                                                            "var36": cmet.s38,
                                                            "var37": cmet.s39,
                                                            "var38": cmet.s40,
                                                            "var39": cmet.s41,
                                                            "var40": cmet.s42,
                                                            "var41": cmet.s43,
                                                            "var42": cmet.s44,
                                                            "var43": cmet.s45,
                                                            "var44": cmet.s46,
                                                            "var45": cmet.s47,
                                                            "var46": cmet.s48
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "TCFDEnvironment":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "TCFDEnvironment"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "TCFDEnvironment"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "TCFDEnvironment"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "TCFDEnvironment",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s30,
                            "var12": cmet.s31
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "TCFDEnvironment",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "TCFDEnvironment"]
                    newMet = {
                        "label": "TCFDEnvironment",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s30,
                                                            "var12": cmet.s31
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "CBIVImpactQuestionnaireProgress":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [_item for _item in db_resultC["carbonmeasure"]
                              if _item["label"] != "Emissions"]

                    if ([_item for _item in db_resultC["carbonmeasure"] if _item["label"] == "Emissions"]):
                        emData = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] == "Emissions"][0]

                        if ([_item for _item in emData["metrics"] if _item["label"] == cmet.s5]):
                            yearData2C = [
                                _item for _item in emData["metrics"] if _item["label"] == cmet.s5][0]
                            if ([_item for _item in yearData2C["value"] if _item["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    _item for _item in yearData2C["value"] if _item["label"] != cmet.s6]
                                customMeasurement2C = []
                                customMeasurement2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [_item for _item in emData["metrics"]
                                           if _item["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            customMeasurement2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [_item for _item in emData["metrics"]
                                       if _item["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": customMeasurement2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [_item for _item in db_result["custommeasure"] if _item["label"] != "CBIVImpactQuestionnaireProgress"]

                if ([_item for _item in db_result["custommeasure"] if _item["label"] == "CBIVImpactQuestionnaireProgress"]):
                    remoteData = [_item for _item in db_result["custommeasure"] if _item["label"] == "CBIVImpactQuestionnaireProgress"][0]
                    if ([_item for _item in remoteData["metrics"] if _item["label"] == cmet.s5]):
                        yearData = [_item for _item in remoteData["metrics"] if _item["label"] == cmet.s5][0]
                        quarterData = [_item for _item in yearData["value"] if _item["label"] != cmet.s6]
                        customMeasurement = []
                        customMeasurement.append({
                            # Environment
                             "environmental-overview": cmet.s1,
                             # Scope emissions
                            "scope-1-emissions": cmet.s2,
                            "scope-2-emissions": cmet.s3,
                            # Scope 2 intermediate progress
                            "scope-2-remote-workers": cmet.s4,
                            "scope-2-electricity": cmet.s7,
                            "scope-2-heat-and-steam": cmet.s8,
                            "scope-3-emissions": cmet.s9,
                            # Scope 3 intermediate progress
                            "scope-3-travel": cmet.s10,
                            "scope-3-commuting": cmet.s11,
                            "scope-3-cloud": cmet.s12,
                            # Social & Governance
                            "employee-overview": cmet.s13,
                            "corporate-diversity": cmet.s14,
                            "corporate-policies": cmet.s15,
                            # Impact
                            "impact-overview": cmet.s16,

                            # Environment
                            "resource-intensity": cmet.s17,
                            "waste-pollutants": cmet.s18,
                            "environmental-reporting": cmet.s19,

                            # Social
                            "pay-gap": cmet.s20,
                            "social-reporting": cmet.s21
                        })
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": customMeasurement
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "CBIVImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        customMeasurement = [{
                            # Environment
                             "environmental-overview": cmet.s1,
                             # Scope emissions
                            "scope-1-emissions": cmet.s2,
                            "scope-2-emissions": cmet.s3,
                            # Scope 2 intermediate progress
                            "scope-2-remote-workers": cmet.s4,
                            "scope-2-electricity": cmet.s7,
                            "scope-2-heat-and-steam": cmet.s8,
                            "scope-3-emissions": cmet.s9,
                            # Scope 3 intermediate progress
                            "scope-3-travel": cmet.s10,
                            "scope-3-commuting": cmet.s11,
                            "scope-3-cloud": cmet.s12,
                            # Social & Governance
                            "employee-overview": cmet.s13,
                            "corporate-diversity": cmet.s14,
                            "corporate-policies": cmet.s15,
                            # Impact
                            "impact-overview": cmet.s16,

                            # Environment
                            "resource-intensity": cmet.s17,
                            "waste-pollutants": cmet.s18,
                            "environmental-reporting": cmet.s19,

                            # Social
                            "pay-gap": cmet.s20,
                            "social-reporting": cmet.s21
                            }]
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "CBIVImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [_item for _item in db_result["custommeasure"]
                            if _item["label"] != "CBIVImpactQuestionnaireProgress"]
                    newMet = {
                        "label": "CBIVImpactQuestionnaireProgress",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            # Environment
                                                            "environmental-overview": cmet.s1,
                                                            # Scope emissions
                                                            "scope-1-emissions": cmet.s2,
                                                            "scope-2-emissions": cmet.s3,
                                                            # Scope 2 intermediate progress
                                                            "scope-2-remote-workers": cmet.s4,
                                                            "scope-2-electricity": cmet.s7,
                                                            "scope-2-heat-and-steam": cmet.s8,
                                                            "scope-3-emissions": cmet.s9,
                                                            # Scope 3 intermediate progress
                                                            "scope-3-travel": cmet.s10,
                                                            "scope-3-commuting": cmet.s11,
                                                            "scope-3-cloud": cmet.s12,
                                                            # Social & Governance
                                                            "employee-overview": cmet.s13,
                                                            "corporate-diversity": cmet.s14,
                                                            "corporate-policies": cmet.s15,
                                                            # Impact
                                                            "impact-overview": cmet.s16,
                                                            
                                                            # Environment
                                                            "resource-intensity": cmet.s17,
                                                            "waste-pollutants": cmet.s18,
                                                            "environmental-reporting": cmet.s19,

                                                            # Social
                                                            "pay-gap": cmet.s20,
                                                            "social-reporting": cmet.s21
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "SocialImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "SocialImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "SocialImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "SocialImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s22,
                            "var6": cmet.s23,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s11,
                            "var12": cmet.s12,
                            "var13": cmet.s13,
                            "var14": cmet.s14,
                            "var15": cmet.s15,
                            "var16": cmet.s16,
                            "var17": cmet.s17,
                            "var18": cmet.s18,
                            "var19": cmet.s19,
                            "var20": cmet.s20,
                            "var21": cmet.s21,
                            "var22": cmet.s24,
                            "var23": cmet.s25,
                            "var24": cmet.s26,
                            "var25": cmet.s27,
                            "var26": cmet.s28,
                            "var27": cmet.s29,
                            "var28": cmet.s30,
                            "var29": cmet.s31,
                            "var30": cmet.s32,
                            "var31": cmet.s33,
                            "var32": cmet.s34,
                            "var33": cmet.s35,
                            "var34": cmet.s36,
                            "var35": cmet.s37
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s22,
                            "var6": cmet.s23,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s11,
                            "var12": cmet.s12,
                            "var13": cmet.s13,
                            "var14": cmet.s14,
                            "var15": cmet.s15,
                            "var16": cmet.s16,
                            "var17": cmet.s17,
                            "var18": cmet.s18,
                            "var19": cmet.s19,
                            "var20": cmet.s20,
                            "var21": cmet.s21,
                            "var22": cmet.s24,
                            "var23": cmet.s25,
                            "var24": cmet.s26,
                            "var25": cmet.s27,
                            "var26": cmet.s28,
                            "var27": cmet.s29,
                            "var28": cmet.s30,
                            "var29": cmet.s31,
                            "var30": cmet.s32,
                            "var31": cmet.s33,
                            "var32": cmet.s34,
                            "var33": cmet.s35,
                            "var34": cmet.s36,
                            "var35": cmet.s37
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "SocialImpact"]
                    newMet = {
                        "label": "SocialImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s22,
                                                            "var6": cmet.s23,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s11,
                                                            "var12": cmet.s12,
                                                            "var13": cmet.s13,
                                                            "var14": cmet.s14,
                                                            "var15": cmet.s15,
                                                            "var16": cmet.s16,
                                                            "var17": cmet.s17,
                                                            "var18": cmet.s18,
                                                            "var19": cmet.s19,
                                                            "var20": cmet.s20,
                                                            "var21": cmet.s21,
                                                            "var22": cmet.s24,
                                                            "var23": cmet.s25,
                                                            "var24": cmet.s26,
                                                            "var25": cmet.s27,
                                                            "var26": cmet.s28,
                                                            "var27": cmet.s29,
                                                            "var28": cmet.s30,
                                                            "var29": cmet.s31,
                                                            "var30": cmet.s32,
                                                            "var31": cmet.s33,
                                                            "var32": cmet.s34,
                                                            "var33": cmet.s35,
                                                            "var34": cmet.s36,
                                                            "var35": cmet.s37
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "ImpactMeasure":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                
                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "ImpactMeasure"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "ImpactMeasure"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "ImpactMeasure"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s7,
                            "var2": cmet.s8,
                            "var3": cmet.s9,
                            "var4": cmet.s10,
                            "var5": cmet.s11,
                            "var6": cmet.s12,
                            "var7": cmet.s13,
                            "var8": cmet.s14,
                            "var9": cmet.s15,
                            "var10": cmet.s16,
                            "var11": cmet.s17,
                            "var12": cmet.s18
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "ImpactMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s7,
                            "var2": cmet.s8,
                            "var3": cmet.s9,
                            "var4": cmet.s10,
                            "var5": cmet.s11,
                            "var6": cmet.s12,
                            "var7": cmet.s13,
                            "var8": cmet.s14,
                            "var9": cmet.s15,
                            "var10": cmet.s16,
                            "var11": cmet.s17,
                            "var12": cmet.s18
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "ImpactMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "ImpactMeasure"]
                    newMet = {
                        "label": "ImpactMeasure",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "var1": cmet.s7,
                                                            "var2": cmet.s8,
                                                            "var3": cmet.s9,
                                                            "var4": cmet.s10,
                                                            "var5": cmet.s11,
                                                            "var6": cmet.s12,
                                                            "var7": cmet.s13,
                                                            "var8": cmet.s14,
                                                            "var9": cmet.s15,
                                                            "var10": cmet.s16,
                                                            "var11": cmet.s17,
                                                            "var12": cmet.s18
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "OncolensImpact2":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "OncolensImpact2"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "OncolensImpact2"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "OncolensImpact2"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "OncolensImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "OncolensImpact2",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "OncolensImpact2"]
                    newMet = {
                        "label": "OncolensImpact2",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9,
                                                            "var8": cmet.s10,
                                                            "var9": cmet.s11,
                                                            "var10": cmet.s12,
                                                            "var11": cmet.s13,
                                                            "var12": cmet.s14
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "IMImpactMeasure":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "IMImpactMeasure"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "IMImpactMeasure"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "IMImpactMeasure"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14,
                            "var13": cmet.s15
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "IMImpactMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14,
                            "var13": cmet.s15
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "IMImpactMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "IMImpactMeasure"]
                    newMet = {
                        "label": "IMImpactMeasure",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9,
                                                            "var8": cmet.s10,
                                                            "var9": cmet.s11,
                                                            "var10": cmet.s12,
                                                            "var11": cmet.s13,
                                                            "var12": cmet.s14,
                                                            "var13": cmet.s15
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "SonioImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "SonioImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "SonioImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "SonioImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "SonioImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "SonioImpact"]
                    newMet = {
                        "label": "SonioImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9,
                                                            "var8": cmet.s10,
                                                            "var9": cmet.s11,
                                                            "var10": cmet.s12,
                                                            "var11": cmet.s13,
                                                            "var12": cmet.s14
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            
    else:
        pass


"""
Endpoint used to update the custom metrics for Valo measurement
"""
@customsroute.post('/custommeasureValo')
async def custom_measure_Valo(cmet: CBIVMeasure):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "EnvironmentalImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }
                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "EnvironmentalImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "EnvironmentalImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "EnvironmentalImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s11,
                            "var12": cmet.s12,
                            "var13": cmet.s13,
                            "var14": cmet.s14
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s11,
                            "var12": cmet.s12,
                            "var13": cmet.s13,
                            "var14": cmet.s14
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "EnvironmentalImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "EnvironmentalImpact"]
                    newMet = {
                        "label": "EnvironmentalImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s11,
                                                            "var12": cmet.s12,
                                                            "var13": cmet.s13,
                                                            "var14": cmet.s14
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "GovernanceImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "GovernanceImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "bool17": cmet.m17,
                            "bool18": cmet.m18,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "bool17": cmet.m17,
                            "bool18": cmet.m18,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "GovernanceImpact"]
                    newMet = {
                        "label": "GovernanceImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "bool17": cmet.m17,
                                                            "bool18": cmet.m18,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "ValoImpactQuestionnaireProgress":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [_item for _item in db_resultC["carbonmeasure"]
                              if _item["label"] != "Emissions"]

                    if ([_item for _item in db_resultC["carbonmeasure"] if _item["label"] == "Emissions"]):
                        emData = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] == "Emissions"][0]

                        if ([_item for _item in emData["metrics"] if _item["label"] == cmet.s5]):
                            yearData2C = [
                                _item for _item in emData["metrics"] if _item["label"] == cmet.s5][0]
                            if ([_item for _item in yearData2C["value"] if _item["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    _item for _item in yearData2C["value"] if _item["label"] != cmet.s6]
                                customMeasurement2C = []
                                customMeasurement2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [_item for _item in emData["metrics"]
                                           if _item["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            customMeasurement2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [_item for _item in emData["metrics"]
                                       if _item["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": customMeasurement2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [_item for _item in db_result["custommeasure"] if _item["label"] != "ValoImpactQuestionnaireProgress"]

                if ([_item for _item in db_result["custommeasure"] if _item["label"] == "ValoImpactQuestionnaireProgress"]):
                    remoteData = [_item for _item in db_result["custommeasure"] if _item["label"] == "ValoImpactQuestionnaireProgress"][0]
                    if ([_item for _item in remoteData["metrics"] if _item["label"] == cmet.s5]):
                        yearData = [_item for _item in remoteData["metrics"] if _item["label"] == cmet.s5][0]
                        quarterData = [_item for _item in yearData["value"] if _item["label"] != cmet.s6]
                        customMeasurement = []
                        customMeasurement.append({
                            # Environment
                            "environmental-overview": cmet.s1,
                            "energy-use": cmet.s2,
                             # Scope emissions
                            "scope-1-emissions": cmet.s3,
                            "scope-2-emissions": cmet.s4,
                            # Scope 2 intermediate progress
                            "scope-2-remote-workers": cmet.s7,
                            "scope-2-electricity": cmet.s8,
                            "scope-2-heat-and-steam": cmet.s9,
                            # Scope 3 progress
                            "scope-3-input": cmet.s10,
                            # Social
                            "social-overview": cmet.s11,
                            "turnover": cmet.s12,
                            "gender-diversity": cmet.s13,
                            "racial-and-ethnic-diversity": cmet.s14,
                            # Governance
                            "governance-overview": cmet.s15,
                            "corporate-policies": cmet.s16,
                            # Impact
                            "impact-summary": cmet.s17,
                        })
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": customMeasurement
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "ValoImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        customMeasurement = [{
                            # Environment
                            "environmental-overview": cmet.s1,
                            "energy-use": cmet.s2,
                             # Scope emissions
                            "scope-1-emissions": cmet.s3,
                            "scope-2-emissions": cmet.s4,
                            # Scope 2 intermediate progress
                            "scope-2-remote-workers": cmet.s7,
                            "scope-2-electricity": cmet.s8,
                            "scope-2-heat-and-steam": cmet.s9,
                            # Scope 3 progress
                            "scope-3-input": cmet.s10,
                            # Social
                            "social-overview": cmet.s11,
                            "turnover": cmet.s12,
                            "gender-diversity": cmet.s13,
                            "racial-and-ethnic-diversity": cmet.s14,
                            # Governance
                            "governance-overview": cmet.s15,
                            "corporate-policies": cmet.s16,
                            # Impact
                            "impact-summary": cmet.s17,
                            }]
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "ValoImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [_item for _item in db_result["custommeasure"]
                            if _item["label"] != "ValoImpactQuestionnaireProgress"]
                    newMet = {
                        "label": "ValoImpactQuestionnaireProgress",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            # Environment
                                                            "environmental-overview": cmet.s1,
                                                            "energy-use": cmet.s2,
                                                            # Scope emissions
                                                            "scope-1-emissions": cmet.s3,
                                                            "scope-2-emissions": cmet.s4,
                                                            # Scope 2 intermediate progress
                                                            "scope-2-remote-workers": cmet.s7,
                                                            "scope-2-electricity": cmet.s8,
                                                            "scope-2-heat-and-steam": cmet.s9,
                                                            # Scope 3 progress
                                                            "scope-3-input": cmet.s10,
                                                            # Social
                                                            "social-overview": cmet.s11,
                                                            "turnover": cmet.s12,
                                                            "gender-diversity": cmet.s13,
                                                            "racial-and-ethnic-diversity": cmet.s14,
                                                            # Governance
                                                            "governance-overview": cmet.s15,
                                                            "corporate-policies": cmet.s16,
                                                            # Impact
                                                            "impact-summary": cmet.s17,
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "SocialImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "SocialImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "SocialImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "SocialImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "SocialImpact"]
                    newMet = {
                        "label": "SocialImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "TurnoverMeasure":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "TurnoverMeasure"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "TurnoverMeasure"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "TurnoverMeasure"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "TurnoverMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s7,
                            "var6": cmet.s8,
                            "var7": cmet.s9,
                            "var8": cmet.s10,
                            "var9": cmet.s11,
                            "var10": cmet.s12,
                            "var11": cmet.s13,
                            "var12": cmet.s14
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "TurnoverMeasure",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "TurnoverMeasure"]
                    newMet = {
                        "label": "TurnoverMeasure",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s7,
                                                            "var6": cmet.s8,
                                                            "var7": cmet.s9,
                                                            "var8": cmet.s10,
                                                            "var9": cmet.s11,
                                                            "var10": cmet.s12,
                                                            "var11": cmet.s13,
                                                            "var12": cmet.s14
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
    else:
        pass


@customsroute.post("/fileuploadValo")
async def upload_files(oid: str = Form(...),
email: str = Form(...), 
metric: str = Form(...), 
fileESG: Optional[UploadFile] = File(None), 
fileDEI: Optional[UploadFile] = File(None), 
fileData: Optional[UploadFile] = File(None), 
fileFamily: Optional[UploadFile] = File(None), 
fileEmployee: Optional[UploadFile] = File(None), 
s5: str = Form(...), s6: str = Form(...)):
    existingFiles = get_files(oid, email, s5, s6, metric)

    if existingFiles:
        uploadedFiles = existingFiles
    else:
        uploadedFiles = {
            "esg": {"file_name": " ", "file_url": " "},
            "dei": {"file_name": " ", "file_url": " "},
            "data": {"file_name": " ", "file_url": " "},
            "family": {"file_name": " ", "file_url": " "},
            "employee": {"file_name": " ", "file_url": " "}
        }


    if fileESG:
        uploadedFiles["esg"] = upload_to_azure_blob(fileESG)
    if fileDEI:
        uploadedFiles["dei"] = upload_to_azure_blob(fileDEI)
    if fileData:
        uploadedFiles["data"] = upload_to_azure_blob(fileData)
    if fileFamily:
        uploadedFiles["family"] = upload_to_azure_blob(fileFamily)
    if fileEmployee:
        uploadedFiles["employee"] = upload_to_azure_blob(fileEmployee)



    db_result = False
    try:
        db_result = read_item(callConnect.container15, oid, email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('read_item failed for /fileuploadCBIV')
        if not db_result:
            return {"status": "error", "message": "Could not fetch item from database"}
        pass

    if db_result:
        if "custommeasure" in db_result:
            if metric:
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                mets = [z for z in db_result["custommeasure"] if z["label"] != metric]
                if ([z for z in db_result["custommeasure"] if z["label"] == metric]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == metric][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != s6]
                        cmeas = []
                        cmeas.append({
                            "esg": {"file_name": uploadedFiles["esg"]["file_name"], "file_url": uploadedFiles["esg"]["file_url"]},
                            "dei": {"file_name": uploadedFiles["dei"]["file_name"], "file_url": uploadedFiles["dei"]["file_url"]},
                            "data": {"file_name": uploadedFiles["data"]["file_name"], "file_url": uploadedFiles["data"]["file_url"]},
                            "family": {"file_name": uploadedFiles["family"]["file_name"], "file_url": uploadedFiles["family"]["file_url"]},
                            "employee": {"file_name": uploadedFiles["employee"]["file_name"], "file_url": uploadedFiles["employee"]["file_url"]}
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != s5]
                        quarterData.append({
                            "label": s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": metric,
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                        return {"status": "success", "message": f"File added successfully to user {email}"}
                    else:
                        cmeas = [{
                            "esg": {"file_name": uploadedFiles["esg"]["file_name"], "file_url": uploadedFiles["esg"]["file_url"]},
                            "dei": {"file_name": uploadedFiles["dei"]["file_name"], "file_url": uploadedFiles["dei"]["file_url"]},
                            "data": {"file_name": uploadedFiles["data"]["file_name"], "file_url": uploadedFiles["data"]["file_url"]},
                            "family": {"file_name": uploadedFiles["family"]["file_name"], "file_url": uploadedFiles["family"]["file_url"]},
                            "employee": {"file_name": uploadedFiles["employee"]["file_name"], "file_url": uploadedFiles["employee"]["file_url"]}
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != s5]
                        tmeas.append({
                            "label": s5,
                            "value": [
                                {
                                    "label": s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": metric,
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                        return {"status": "success", "message": f"File added successfully to user {email}"}

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != metric]
                    newMet = {
                        "label": metric,
                        "metrics": [
                            {
                                "label": s5,
                                "value": [
                                    {
                                        "label": s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "esg": {"file_name": uploadedFiles["esg"]["file_name"], "file_url": uploadedFiles["esg"]["file_url"]},
                                                            "dei": {"file_name": uploadedFiles["dei"]["file_name"], "file_url": uploadedFiles["dei"]["file_url"]},
                                                            "data": {"file_name": uploadedFiles["data"]["file_name"], "file_url": uploadedFiles["data"]["file_url"]},
                                                            "family": {"file_name": uploadedFiles["family"]["file_name"], "file_url": uploadedFiles["family"]["file_url"]},
                                                            "employee": {"file_name": uploadedFiles["employee"]["file_name"], "file_url": uploadedFiles["employee"]["file_url"]}
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
                    return {"status": "success", "message": f"File added successfully to user {email}"}
    else:
        pass


"""
Endpoint used to update the custom metrics for Knight measurement
"""
@customsroute.post('/custommeasureKnight')
async def custom_measure_KNIGHT(cmet: CBIVMeasure):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "GovernanceImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"] if z["label"] != "Emissions"]
                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"] if z["label"] != "GovernanceImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"]):
                    remoteData = [z for z in db_result["custommeasure"] if z["label"] == "GovernanceImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"] if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4
                        })
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "GovernanceImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "GovernanceImpact"]
                    newMet = {
                        "label": "GovernanceImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "CBIVImpactQuestionnaireProgress":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [_item for _item in db_resultC["carbonmeasure"]
                              if _item["label"] != "Emissions"]

                    if ([_item for _item in db_resultC["carbonmeasure"] if _item["label"] == "Emissions"]):
                        emData = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] == "Emissions"][0]

                        if ([_item for _item in emData["metrics"] if _item["label"] == cmet.s5]):
                            yearData2C = [
                                _item for _item in emData["metrics"] if _item["label"] == cmet.s5][0]
                            if ([_item for _item in yearData2C["value"] if _item["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    _item for _item in yearData2C["value"] if _item["label"] != cmet.s6]
                                customMeasurement2C = []
                                customMeasurement2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [_item for _item in emData["metrics"]
                                           if _item["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            customMeasurement2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [_item for _item in emData["metrics"]
                                       if _item["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": customMeasurement2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [_item for _item in db_resultC["carbonmeasure"]
                                  if _item["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [_item for _item in db_result["custommeasure"] if _item["label"] != "CBIVImpactQuestionnaireProgress"]

                if ([_item for _item in db_result["custommeasure"] if _item["label"] == "CBIVImpactQuestionnaireProgress"]):
                    remoteData = [_item for _item in db_result["custommeasure"] if _item["label"] == "CBIVImpactQuestionnaireProgress"][0]
                    if ([_item for _item in remoteData["metrics"] if _item["label"] == cmet.s5]):
                        yearData = [_item for _item in remoteData["metrics"] if _item["label"] == cmet.s5][0]
                        quarterData = [_item for _item in yearData["value"] if _item["label"] != cmet.s6]
                        customMeasurement = []
                        customMeasurement.append({
                            # Environment
                             "environmental-overview": cmet.s1,
                             # Scope emissions
                            "scope-1-emissions": cmet.s2,
                            "scope-2-emissions": cmet.s3,
                            # Scope 2 intermediate progress
                            "scope-2-remote-workers": cmet.s4,
                            "scope-2-electricity": cmet.s7,
                            "scope-2-heat-and-steam": cmet.s8,
                            "scope-3-emissions": cmet.s9,
                            # Scope 3 intermediate progress
                            "scope-3-travel": cmet.s10,
                            "scope-3-commuting": cmet.s11,
                            "scope-3-cloud": cmet.s12,
                            # Social & Governance
                            "employee-overview": cmet.s13,
                            "corporate-diversity": cmet.s14,
                            "corporate-policies": cmet.s15,
                            # Impact
                            "impact-overview": cmet.s16
                        })
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": customMeasurement
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "CBIVImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        customMeasurement = [{
                            # Environment
                             "environmental-overview": cmet.s1,
                             # Scope emissions
                            "scope-1-emissions": cmet.s2,
                            "scope-2-emissions": cmet.s3,
                            # Scope 2 intermediate progress
                            "scope-2-remote-workers": cmet.s4,
                            "scope-2-electricity": cmet.s7,
                            "scope-2-heat-and-steam": cmet.s8,
                            "scope-3-emissions": cmet.s9,
                            # Scope 3 intermediate progress
                            "scope-3-travel": cmet.s10,
                            "scope-3-commuting": cmet.s11,
                            "scope-3-cloud": cmet.s12,
                            # Social & Governance
                            "employee-overview": cmet.s13,
                            "corporate-diversity": cmet.s14,
                            "corporate-policies": cmet.s15,
                            # Impact
                            "impact-overview": cmet.s16
                            }]
                        tmeas = [_item for _item in remoteData["metrics"]
                                 if _item["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": customMeasurement
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "CBIVImpactQuestionnaireProgress",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [_item for _item in db_result["custommeasure"]
                            if _item["label"] != "CBIVImpactQuestionnaireProgress"]
                    newMet = {
                        "label": "CBIVImpactQuestionnaireProgress",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            # Environment
                                                            "environmental-overview": cmet.s1,
                                                            # Scope emissions
                                                            "scope-1-emissions": cmet.s2,
                                                            "scope-2-emissions": cmet.s3,
                                                            # Scope 2 intermediate progress
                                                            "scope-2-remote-workers": cmet.s4,
                                                            "scope-2-electricity": cmet.s7,
                                                            "scope-2-heat-and-steam": cmet.s8,
                                                            "scope-3-emissions": cmet.s9,
                                                            # Scope 3 intermediate progress
                                                            "scope-3-travel": cmet.s10,
                                                            "scope-3-commuting": cmet.s11,
                                                            "scope-3-cloud": cmet.s12,
                                                            # Social & Governance
                                                            "employee-overview": cmet.s13,
                                                            "corporate-diversity": cmet.s14,
                                                            "corporate-policies": cmet.s15,
                                                            # Impact
                                                            "impact-overview": cmet.s16
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            elif cmet.metric == "SocialImpact":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "SocialImpact"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "SocialImpact"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "SocialImpact"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s11,
                            "var12": cmet.s12,
                            "var13": cmet.s13,
                            "var14": cmet.s14,
                            "var15": cmet.s15,
                            "var16": cmet.s16,
                            "var17": cmet.s17,
                            "var18": cmet.s18,
                            "var19": cmet.s19,
                            "var20": cmet.s20,
                            "var21": cmet.s21,
                            "var22": cmet.s22,
                            "var23": cmet.s23
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "bool1": cmet.m1,
                            "bool2": cmet.m2,
                            "bool3": cmet.m3,
                            "bool4": cmet.m4,
                            "bool5": cmet.m5,
                            "bool6": cmet.m6,
                            "bool7": cmet.m7,
                            "bool8": cmet.m8,
                            "bool9": cmet.m9,
                            "bool10": cmet.m10,
                            "bool11": cmet.m11,
                            "bool12": cmet.m12,
                            "bool13": cmet.m13,
                            "bool14": cmet.m14,
                            "bool15": cmet.m15,
                            "bool16": cmet.m16,
                            "var1": cmet.s1,
                            "var2": cmet.s2,
                            "var3": cmet.s3,
                            "var4": cmet.s4,
                            "var5": cmet.s28,
                            "var6": cmet.s29,
                            "var7": cmet.s7,
                            "var8": cmet.s8,
                            "var9": cmet.s9,
                            "var10": cmet.s10,
                            "var11": cmet.s11,
                            "var12": cmet.s12,
                            "var13": cmet.s13,
                            "var14": cmet.s14,
                            "var15": cmet.s15,
                            "var16": cmet.s16,
                            "var17": cmet.s17,
                            "var18": cmet.s18,
                            "var19": cmet.s19,
                            "var20": cmet.s20,
                            "var21": cmet.s21,
                            "var22": cmet.s22,
                            "var23": cmet.s23
                        }]
                        tmeas = [a for a in remoteData["metrics"] if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "SocialImpact",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"] if z["label"] != "SocialImpact"]
                    newMet = {
                        "label": "SocialImpact",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "bool1": cmet.m1,
                                                            "bool2": cmet.m2,
                                                            "bool3": cmet.m3,
                                                            "bool4": cmet.m4,
                                                            "bool5": cmet.m5,
                                                            "bool6": cmet.m6,
                                                            "bool7": cmet.m7,
                                                            "bool8": cmet.m8,
                                                            "bool9": cmet.m9,
                                                            "bool10": cmet.m10,
                                                            "bool11": cmet.m11,
                                                            "bool12": cmet.m12,
                                                            "bool13": cmet.m13,
                                                            "bool14": cmet.m14,
                                                            "bool15": cmet.m15,
                                                            "bool16": cmet.m16,
                                                            "var1": cmet.s1,
                                                            "var2": cmet.s2,
                                                            "var3": cmet.s3,
                                                            "var4": cmet.s4,
                                                            "var5": cmet.s28,
                                                            "var6": cmet.s29,
                                                            "var7": cmet.s7,
                                                            "var8": cmet.s8,
                                                            "var9": cmet.s9,
                                                            "var10": cmet.s10,
                                                            "var11": cmet.s11,
                                                            "var12": cmet.s12,
                                                            "var13": cmet.s13,
                                                            "var14": cmet.s14,
                                                            "var15": cmet.s15,
                                                            "var16": cmet.s16,
                                                            "var17": cmet.s17,
                                                            "var18": cmet.s18,
                                                            "var19": cmet.s19,
                                                            "var20": cmet.s20,
                                                            "var21": cmet.s21,
                                                            "var22": cmet.s22,
                                                            "var23": cmet.s23
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
            
    else:
        pass



"""
Endpoint used to update the custom metrics for renew measurement
"""
@customsroute.post('/custommeasureD')
async def custom_measure_renew(cmet: RenewDiv):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "CorporateDiversity":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "CorporateDiversity"]
                if ([z for z in db_result["custommeasure"] if z["label"] == "CorporateDiversity"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "CorporateDiversity"][0]
                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "organizationDiscloseY": cmet.m1,
                            "codeConductY": cmet.m2,
                            "deiPoliciesY": cmet.m3,
                            "disclosePerformance": cmet.s1,
                            "numberCLevel": cmet.s2,
                            "numberBoard": cmet.s3,
                            "numberIndividuals": cmet.s4,
                            "numberReporting": cmet.s7,
                            "numberReportingPrior": cmet.s8,
                            "netChange": cmet.s9,
                            "annualTurnover": cmet.s10,
                            "womenTC": cmet.s11,
                            "womenC": cmet.s12,
                            "womenB": cmet.s13,
                            "diverseTC": cmet.s14,
                            "diverseC": cmet.s15,
                            "diverseB": cmet.s16,
                            "indigenousTC": cmet.s17,
                            "indigenousC": cmet.s18,
                            "indigenousB": cmet.s19,
                            "lgbTC": cmet.s20,
                            "lgbC": cmet.s21,
                            "lgbB": cmet.s22,
                            "veteranTC": cmet.s23,
                            "veteranC": cmet.s24,
                            "veteranB": cmet.s25,
                            "disabilityTC": cmet.s26,
                            "disabilityC": cmet.s27,
                            "disabilityB": cmet.s28
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "CorporateDiversity",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "energyConsumed": cmet.s1,
                            "renewableConsumed": cmet.s2
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "CorporateDiversity",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "CorporateDiversity"]
                    newMet = {
                        "label": "CorporateDiversity",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "organizationDiscloseY": cmet.m1,
                                                            "codeConductY": cmet.m2,
                                                            "deiPoliciesY": cmet.m3,
                                                            "disclosePerformance": cmet.s1,
                                                            "numberCLevel": cmet.s2,
                                                            "numberBoard": cmet.s3,
                                                            "numberIndividuals": cmet.s4,
                                                            "numberReporting": cmet.s7,
                                                            "numberReportingPrior": cmet.s8,
                                                            "netChange": cmet.s9,
                                                            "annualTurnover": cmet.s10,
                                                            "womenTC": cmet.s11,
                                                            "womenC": cmet.s12,
                                                            "womenB": cmet.s13,
                                                            "diverseTC": cmet.s14,
                                                            "diverseC": cmet.s15,
                                                            "diverseB": cmet.s16,
                                                            "indigenousTC": cmet.s17,
                                                            "indigenousC": cmet.s18,
                                                            "indigenousB": cmet.s19,
                                                            "lgbTC": cmet.s20,
                                                            "lgbC": cmet.s21,
                                                            "lgbB": cmet.s22,
                                                            "veteranTC": cmet.s23,
                                                            "veteranC": cmet.s24,
                                                            "veteranB": cmet.s25,
                                                            "disabilityTC": cmet.s26,
                                                            "disabilityC": cmet.s27,
                                                            "disabilityB": cmet.s28
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)

    else:
        pass


"""
Endpoint used to update the impact measurement
"""


@customsroute.post('/custommeasureim')
async def custom_measure(cmet: IMMeasure):
    db_result = False
    try:
        db_result = read_item(callConnect.container15, cmet.oid, cmet.email)
    except exceptions.CosmosHttpResponseError as e:
        logging.error('This is an error message for /custommeasure')
        pass

    if db_result:
        if "custommeasure" in db_result:
            if cmet.metric == "ImpactMeasurement":
                user = {
                    "id": db_result["id"],
                    "email": db_result["email"],
                    "custommeasure": []
                }

                try:
                    db_resultC = read_item(
                        callConnect.container7, cmet.oid, cmet.email)
                except exceptions.CosmosHttpResponseError as e:
                    logging.error(
                        'This is an error message for /custommeasure')
                    return {"url": "/", "atype": False}

                if "carbonmeasure" in db_resultC:
                    user2C = {
                        "id": db_resultC["id"],
                        "email": db_resultC["email"],
                        "carbonmeasure": []
                    }
                    mets2C = [z for z in db_resultC["carbonmeasure"]
                              if z["label"] != "Emissions"]

                    if ([z for z in db_resultC["carbonmeasure"] if z["label"] == "Emissions"]):
                        emData = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] == "Emissions"][0]

                        if ([a for a in emData["metrics"] if a["label"] == cmet.s5]):
                            yearData2C = [
                                aa for aa in emData["metrics"] if aa["label"] == cmet.s5][0]
                            if ([bb for bb in yearData2C["value"] if bb["label"] == cmet.s6]):
                                pass
                            else:
                                quarterData2C = [
                                    bb for bb in yearData2C["value"] if bb["label"] != cmet.s6]
                                cmeas2C = []
                                cmeas2C.append({
                                    "scope1": 0,
                                    "scope2": 0,
                                    "scope3": 0
                                })
                                tmeas2C = [a for a in emData["metrics"]
                                           if a["label"] != cmet.s5]
                                quarterData2C.append({
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas2C
                                        }
                                    ]
                                })
                                tmeas2C.append({
                                    "label": cmet.s5,
                                    "value": quarterData2C
                                })
                                newMet2C = {
                                    "label": "Emissions",
                                    "metrics": tmeas2C
                                }
                                mets2C.append(newMet2C)
                                target2C = {
                                    "carbonmeasure": mets2C
                                }
                                user2C.update(target2C)
                                callConnect.container7.upsert_item(body=user2C)
                        else:
                            cmeas2C = [{
                                "scope1": 0,
                                "scope2": 0,
                                "scope3": 0
                            }]
                            tmeas2C = [a for a in emData["metrics"]
                                       if a["label"] != cmet.s5]
                            tmeas2C.append({
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value": cmeas2C
                                            }
                                        ]
                                    }
                                ]
                            })
                            newMet2C = {
                                "label": "Emissions",
                                "metrics": tmeas2C
                            }
                            mets2C.append(newMet2C)
                            target2C = {
                                "carbonmeasure": mets2C
                            }
                            user2C.update(target2C)
                            callConnect.container7.upsert_item(body=user2C)

                    else:
                        user2C = {
                            "id": db_resultC["id"],
                            "email": db_resultC["email"],
                            "carbonmeasure": []
                        }
                        mets2C = [z for z in db_resultC["carbonmeasure"]
                                  if z["label"] != "Emissions"]
                        newMet2C = {
                            "label": "Emissions",
                            "metrics": [
                                {
                                    "label": cmet.s5,
                                    "value": [
                                        {
                                            "label": cmet.s6,
                                            "metrics": [
                                                {
                                                    "label": "1",
                                                    "value":
                                                        [
                                                            {
                                                                "scope1": 0,
                                                                "scope2": 0,
                                                                "scope3": 0
                                                            }
                                                        ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                        mets2C.append(newMet2C)
                        target2C = {
                            "carbonmeasure": mets2C
                        }
                        user2C.update(target2C)
                        callConnect.container7.upsert_item(body=user2C)

                mets = [z for z in db_result["custommeasure"]
                        if z["label"] != "ImpactMeasurement"]

                if ([z for z in db_result["custommeasure"] if z["label"] == "ImpactMeasurement"]):
                    remoteData = [z for z in db_result["custommeasure"]
                                  if z["label"] == "ImpactMeasurement"][0]

                    if ([a for a in remoteData["metrics"] if a["label"] == cmet.s5]):
                        yearData = [aa for aa in remoteData["metrics"]
                                    if aa["label"] == cmet.s5][0]
                        quarterData = [
                            bb for bb in yearData["value"] if bb["label"] != cmet.s6]
                        cmeas = []
                        cmeas.append({
                            "productName": cmet.s1,
                            "carbonEmissions": cmet.s2,
                            "defineUnit": cmet.s3,
                            "energyAmount": cmet.s4,
                            "unitMeasure": cmet.s13,
                            "replacedMaterial": cmet.s14,
                            "cradleGate": cmet.m1,
                            "sales18": cmet.s7,
                            "sales19": cmet.s8,
                            "sales20": cmet.s9,
                            "sales21": cmet.s10,
                            "sales22": cmet.s11,
                            "sales27": cmet.s12,
                            "carbonEmissions2": cmet.s15,
                            "defineUnit2": cmet.s16
                        })
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        quarterData.append({
                            "label": cmet.s6,
                            "metrics": [
                                {
                                    "label": "1",
                                    "value": cmeas
                                }
                            ]
                        })
                        tmeas.append({
                            "label": cmet.s5,
                            "value": quarterData
                        })
                        newMet = {
                            "label": "ImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)
                    else:
                        cmeas = [{
                            "productName": cmet.s1,
                            "carbonEmissions": cmet.s2,
                            "defineUnit": cmet.s3,
                            "energyAmount": cmet.s4,
                            "unitMeasure": cmet.s13,
                            "replacedMaterial": cmet.s14,
                            "cradleGate": cmet.m1,
                            "sales18": cmet.s7,
                            "sales19": cmet.s8,
                            "sales20": cmet.s9,
                            "sales21": cmet.s10,
                            "sales22": cmet.s11,
                            "sales27": cmet.s12,
                            "carbonEmissions2": cmet.s15,
                            "defineUnit2": cmet.s16
                        }]
                        tmeas = [a for a in remoteData["metrics"]
                                 if a["label"] != cmet.s5]
                        tmeas.append({
                            "label": cmet.s5,
                            "value": [
                                {
                                    "label": cmet.s6,
                                    "metrics": [
                                        {
                                            "label": "1",
                                            "value": cmeas
                                        }
                                    ]
                                }
                            ]
                        })
                        newMet = {
                            "label": "ImpactMeasurement",
                            "metrics": tmeas
                        }
                        mets.append(newMet)
                        target = {
                            "custommeasure": mets
                        }
                        user.update(target)
                        callConnect.container15.upsert_item(body=user)

                else:
                    user = {
                        "id": db_result["id"],
                        "email": db_result["email"],
                        "custommeasure": []
                    }
                    mets = [z for z in db_result["custommeasure"]
                            if z["label"] != "ImpactMeasurement"]
                    newMet = {
                        "label": "ImpactMeasurement",
                        "metrics": [
                            {
                                "label": cmet.s5,
                                "value": [
                                    {
                                        "label": cmet.s6,
                                        "metrics": [
                                            {
                                                "label": "1",
                                                "value":
                                                    [
                                                        {
                                                            "productName": cmet.s1,
                                                            "carbonEmissions": cmet.s2,
                                                            "defineUnit": cmet.s3,
                                                            "energyAmount": cmet.s4,
                                                            "unitMeasure": cmet.s13,
                                                            "replacedMaterial": cmet.s14,
                                                            "cradleGate": cmet.m1,
                                                            "sales18": cmet.s7,
                                                            "sales19": cmet.s8,
                                                            "sales20": cmet.s9,
                                                            "sales21": cmet.s10,
                                                            "sales22": cmet.s11,
                                                            "sales27": cmet.s12,
                                                            "carbonEmissions2": cmet.s15,
                                                            "defineUnit2": cmet.s16
                                                        }
                                                    ]
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                    mets.append(newMet)
                    target = {
                        "custommeasure": mets
                    }
                    user.update(target)
                    callConnect.container15.upsert_item(body=user)
    else:
        pass
